
CREATE TABLE EstadoPais
(
	idEstadoPais NUMBER NOT NULL,
	descripcion VARCHAR (200) NOT NULL,
	fechabaja	DATE,
	CONSTRAINT PK_EstadoPais PRIMARY KEY (idEstadoPais)
);


CREATE SEQUENCE seq_idEstadoPais INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idEstadoPais
  BEFORE INSERT ON EstadoPais
  FOR EACH ROW
BEGIN
  SELECT seq_idEstadoPais.NEXTVAL INTO :NEW.idEstadoPais
  FROM DUAL;
END insert_idEstadoPais;
/

CREATE TABLE Region
(
	idRegion NUMBER NOT NULL,
	descripcion VARCHAR (100) NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_Region PRIMARY KEY (idRegion)
);


CREATE SEQUENCE seq_idRegion INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idRegion
  BEFORE INSERT ON Region
  FOR EACH ROW
BEGIN
  SELECT seq_idRegion.NEXTVAL INTO :NEW.idRegion
  FROM DUAL;
END insert_idRegion;
/


CREATE TABLE Parlamento
(
	idParlamento NUMBER NOT NULL,
	nombre VARCHAR (100) NOT NULL,
	numeroParlamentarios NUMBER NOT NULL,
	direccionFisica VARCHAR (200),
	telefono VARCHAR (20),
	direccionWeb VARCHAR (150),
	idEstadoPais NUMBER,
	idRegion NUMBER,
	fechabaja	DATE,	
	CONSTRAINT PK_Parlamento PRIMARY KEY (idParlamento),
	CONSTRAINT FK_Parlamento_0 FOREIGN KEY (idEstadoPais) REFERENCES EstadoPais (idEstadoPais),
	CONSTRAINT FK_Parlamento_1 FOREIGN KEY (idRegion) REFERENCES Region (idRegion)
);


CREATE SEQUENCE seq_idParlamento INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idparlamento
  BEFORE INSERT ON Parlamento
  FOR EACH ROW
BEGIN
  SELECT seq_idParlamento.NEXTVAL INTO :NEW.idParlamento
  FROM DUAL;
END insert_idParlamento;
/

CREATE TABLE Partido
(
	idPartido NUMBER NOT NULL,
	descripcion VARCHAR (100) NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_Partido PRIMARY KEY (idPartido)
);

CREATE SEQUENCE seq_idPartido INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idpartido
  BEFORE INSERT ON Partido
  FOR EACH ROW
BEGIN
  SELECT seq_idPartido.NEXTVAL INTO :NEW.idPartido
  FROM DUAL;
END insert_idPartido;
/

CREATE TABLE Parlamentario
(
	idParlamento NUMBER NOT NULL,
	idParlamentario NUMBER NOT NULL,
	nombreApellidos VARCHAR (200) NOT NULL,
	idPartido NUMBER NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_Parlamentario PRIMARY KEY (idParlamento, idParlamentario),
	CONSTRAINT FK_Parlamentario_0 FOREIGN KEY (idParlamento) REFERENCES Parlamento (idParlamento),
	CONSTRAINT FK_UltimoPartido_1 FOREIGN KEY (idPartido) REFERENCES Partido (idPartido)
);




CREATE TABLE Iva
(
	idIva NUMBER NOT NULL,
	descripcion VARCHAR (100) NOT NULL,
	porcentaje NUMBER (5, 2) NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_Iva PRIMARY KEY (idIva)
);


CREATE SEQUENCE seq_idIva INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idIva
  BEFORE INSERT ON Iva
  FOR EACH ROW
BEGIN
  SELECT seq_idIva.NEXTVAL INTO :NEW.idIva
  FROM DUAL;
END insert_idIva;
/


CREATE TABLE Gasto
(
	IdCategoriaGasto NUMBER NOT NULL,
	descripcion VARCHAR (100) NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_Gasto PRIMARY KEY (IdCategoriaGasto)
);

CREATE SEQUENCE seq_idCategoriaGasto INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idcategoriagasto
  BEFORE INSERT ON Gasto
  FOR EACH ROW
BEGIN
  SELECT seq_idCategoriaGasto.NEXTVAL INTO :NEW.IdCategoriaGasto
  FROM DUAL;
END insert_idcategoriagasto;
/



CREATE TABLE GastoParlamentario
(
	IdCategoriaGasto NUMBER NOT NULL,
	CONSTRAINT PK_GastoParlamentario PRIMARY KEY (IdCategoriaGasto),
	CONSTRAINT FK_GastoParlamentario_0 FOREIGN KEY (IdCategoriaGasto) REFERENCES Gasto (IdCategoriaGasto)
);


CREATE TABLE GastoParlamento
(
	IdCategoriaGasto NUMBER NOT NULL,
	CONSTRAINT PK_GastoParlamento PRIMARY KEY (IdCategoriaGasto),
	CONSTRAINT FK_GastoParlamento_0 FOREIGN KEY (IdCategoriaGasto) REFERENCES Gasto (IdCategoriaGasto)
);


CREATE TABLE EstadoGasto
(
	idEstadoGasto NUMBER NOT NULL,
	descripcion VARCHAR (100) NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_EstadoGasto PRIMARY KEY (idEstadoGasto)
);

CREATE SEQUENCE seq_idEstadoGasto INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idestadogasto
  BEFORE INSERT ON EstadoGasto
  FOR EACH ROW
BEGIN
  SELECT seq_idEstadoGasto.NEXTVAL INTO :NEW.idEstadoGasto
  FROM DUAL;
END insert_idestadogasto;
/




CREATE TABLE FormaPago
(
	idFormaPago NUMBER NOT NULL,
	descripcion VARCHAR (100) NOT NULL,
	fechabaja	DATE,	
	CONSTRAINT PK_FormaPago PRIMARY KEY (idFormaPago)
);
CREATE SEQUENCE seq_idFormaPago INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idformapago
  BEFORE INSERT ON FormaPago
  FOR EACH ROW
BEGIN
  SELECT seq_idFormaPago.NEXTVAL INTO :NEW.idFormaPago
  FROM DUAL;
END insert_idformapago;
/


CREATE TABLE FormaPagoParlamentario
(
	idFormaPago NUMBER NOT NULL,
	CONSTRAINT PK_FParlamentario PRIMARY KEY (idFormaPago),
	CONSTRAINT FK_FParlamentario_0 FOREIGN KEY (idFormaPago) REFERENCES FormaPago (idFormaPago)
);


CREATE TABLE FormaPagoParlamento
(
	idFormaPago NUMBER NOT NULL,
	CONSTRAINT PK_FParlamento PRIMARY KEY (idFormaPago),
	CONSTRAINT FK_FParlamento_0 FOREIGN KEY (idFormaPago) REFERENCES FormaPago (idFormaPago)
);




CREATE TABLE Estado
(
	idEstadoPais NUMBER NOT NULL,
	CONSTRAINT PK_Estado PRIMARY KEY (idEstadoPais),
	CONSTRAINT FK_Estado_0 FOREIGN KEY (idEstadoPais) REFERENCES EstadoPais (idEstadoPais)
);


CREATE TABLE Pais
(
	idEstadoPais NUMBER NOT NULL,
	CONSTRAINT PK_Pais PRIMARY KEY (idEstadoPais),
	CONSTRAINT FK_Pais_0 FOREIGN KEY (idEstadoPais) REFERENCES EstadoPais (idEstadoPais)
);




CREATE TABLE HistoricoGastoParlamentario
(
	fecha DATE NOT NULL,
	IdCategoriaGasto NUMBER NOT NULL, 
	idParlamento NUMBER NOT NULL,
	idParlamentario NUMBER NOT NULL,
	idPartido NUMBER NOT NULL,
	importesinIva NUMBER (10, 2) NOT NULL,
	nifEmpresa VARCHAR (50),
	descripcionTextual VARCHAR (500) NOT NULL,
	justificacionTextual VARCHAR (500) NOT NULL,
	urlInformacion VARCHAR (100),
	idIva NUMBER NOT NULL,
	idEstadoGasto NUMBER NOT NULL,
	idFormaPago NUMBER NOT NULL,
	CONSTRAINT PK_HGParlamentario PRIMARY KEY (fecha, IdCategoriaGasto, idParlamento, idParlamentario),
	CONSTRAINT FK_HGParlamentario_1 FOREIGN KEY (IdCategoriaGasto) REFERENCES GastoParlamentario (IdCategoriaGasto),
	CONSTRAINT FK_HGParlamentario_2 FOREIGN KEY (idParlamento, idParlamentario) REFERENCES Parlamentario (idParlamento, idParlamentario),
	CONSTRAINT FK_HGParlamentario_3 FOREIGN KEY (idIva) REFERENCES Iva (idIva),
	CONSTRAINT FK_HGParlamentario_4 FOREIGN KEY (idEstadoGasto) REFERENCES EstadoGasto (idEstadoGasto),
	CONSTRAINT FK_HGParlamentario_5 FOREIGN KEY (idFormaPago) REFERENCES FormaPagoParlamentario (idFormaPago),
    	CONSTRAINT FK_HGParlamentario_6 FOREIGN KEY (IDPARTIDO) REFERENCES PARTIDO (IDPARTIDO)
);


CREATE TABLE HistoricoGastoParlamento
(
	idParlamento NUMBER,
	IdCategoriaGasto NUMBER,
	fecha DATE,
	importesinIva NUMBER (10, 2),
	nifEmpresa VARCHAR (50),
	descripcionTextual VARCHAR (500),
	justificacionTextual VARCHAR (500),
	urlInformacion VARCHAR (100),
	idIva NUMBER NOT NULL,
	idEstadoGasto NUMBER NOT NULL,
	idFormaPago NUMBER NOT NULL,
	CONSTRAINT PK_HGParlamento PRIMARY KEY (idParlamento, IdCategoriaGasto, fecha),
	CONSTRAINT FK_HGParlamento_0 FOREIGN KEY (idParlamento) REFERENCES Parlamento (idParlamento),
	CONSTRAINT FK_HGParlamento_1 FOREIGN KEY (IdCategoriaGasto) REFERENCES GastoParlamento (IdCategoriaGasto),
	CONSTRAINT FK_HGParlamento_3 FOREIGN KEY (idEstadoGasto) REFERENCES EstadoGasto (idEstadoGasto),
	CONSTRAINT FK_HGParlamento_4 FOREIGN KEY (idFormaPago) REFERENCES FormaPagoParlamento (idFormaPago),
	CONSTRAINT FK_HGParlamento_5 FOREIGN KEY (idIva) REFERENCES Iva (idIva)
);


CREATE TABLE Logs
(
  	idLog          NUMBER NOT NULL,
	fecha          DATE NOT NULL,
  	procedimiento  VARCHAR2(200),
  	parentrada  	 VARCHAR2(2000),
  	parsalida      VARCHAR2(2000),
	CONSTRAINT PK_Logs PRIMARY KEY (idLog)
);
CREATE SEQUENCE seq_idLog INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE TRIGGER insert_idlog
  BEFORE INSERT ON Logs
  FOR EACH ROW
BEGIN
  SELECT seq_idLog.NEXTVAL INTO :NEW.idLog
  FROM DUAL;
END insert_idlog;
/


CREATE TABLE EST1
(
  	IDPARLAMENTO    NUMBER NOT NULL,
    	NOMBRE          VARCHAR2(200) NOT NULL,
  	TOTALGASTO  	  NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST1 PRIMARY KEY (IDPARLAMENTO)
);

CREATE TABLE EST2
(
  	IDPARLAMENTO    NUMBER NOT NULL,
    	NOMBRE          VARCHAR2(200) NOT NULL,
        ANYO          NUMBER NOT NULL,
  	DIFERENCIA  	  NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST2 PRIMARY KEY (IDPARLAMENTO,ANYO)
);

CREATE TABLE EST3
(
  	IDPARLAMENTO    NUMBER NOT NULL,
    	NOMBRE          VARCHAR2(200) NOT NULL,
        ANYO          NUMBER NOT NULL,
  	GASTOALTO  	  NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST3 PRIMARY KEY (ANYO)
);

CREATE TABLE EST4
(
  	IDPARLAMENTO    NUMBER NOT NULL,
    	IDPARLAMENTARIO NUMBER NOT NULL,
    	NOMBREAPELLIDOS VARCHAR2(200) NOT NULL,
  	GASTOTOTAL  	  NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST4 PRIMARY KEY (IDPARLAMENTO,IDPARLAMENTARIO)
);

CREATE TABLE EST5
(
    	ANYO            NUMBER NOT NULL,
  	PROMEDIO  	    NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST5 PRIMARY KEY (ANYO)
);

CREATE TABLE EST6
(
    ANYO                NUMBER NOT NULL,
	IDPARLAMENTOMAS  	NUMBER NOT NULL,
  	IDPARLAMENTARIOMAS  NUMBER NOT NULL,
    NPARLAMENTARIOMAS     VARCHAR(200) NOT NULL,
    IMPORTEMAS          NUMBER(10,2) NOT NULL,
	IDPARLAMENTOMEN  	NUMBER NOT NULL,	
    IDPARLAMENTARIOMEN  NUMBER NOT NULL,
    NPARLAMENTARIOMEN     VARCHAR(200) NOT NULL,
    IMPORTEMEN          NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST6 PRIMARY KEY (ANYO)
);

CREATE TABLE EST7
(
    ANYO                NUMBER NOT NULL,
    NOMBRE              VARCHAR(200) NOT NULL,
    PROMEDIO            NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST7 PRIMARY KEY (ANYO)
);

CREATE TABLE EST8
(
    ANYO         NUMBER NOT NULL,
    TOTAL        NUMBER(10,2) NOT NULL,
	CONSTRAINT PK_EST8 PRIMARY KEY (ANYO)
);
