create or replace
PROCEDURE ALTAEST2
(
  idParlamento_ IN EST2.idParlamento%TYPE, 
  nombre_ IN EST2.nombre%TYPE,
  anyo_ IN EST2.anyo%TYPE,
  diferencia_ IN EST2.diferencia%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      ALTAEST2
   PROPSITO:   gestiona el alta de un nuevo registro en la tabla EST2

   PARAMETERS:  idParlamento_, nombre_,anyo_,diferencia_, rsp
   INPUT:       idParlamento_, nombre_,anyo_,diferencia_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altaEST2('1','Parlament Catalan','2012','100',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PARLAMENTO_NUL  EXCEPTION;
E_NOMBRE_NUL  EXCEPTION;
E_DIF_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
contador      INTEGER;
E_INEX_PARLAMENTO EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idParlamento_: '||idparlamento_||' nombre_: '||nombre_||' anyo_:'||anyo_||
    'diferencia_: '||diferencia_;

	--verificamos que los campos no nulos no sean nulos
	IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;
	END IF;
	IF (nombre_ IS NULL) THEN
		RAISE E_NOMBRE_NUL;
	END IF;  
	IF (diferencia_ IS NULL) THEN
		RAISE E_DIF_NUL;
	END IF;
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;	 

  --Busco en la tabla de parlamentos si existe un parlamento con este id
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO
    WHERE IDPARLAMENTO=idparlamento_;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;
    
    
	INSERT INTO EST2(idparlamento,nombre,anyo,diferencia) VALUES(idparlamento_,nombre_,anyo_,diferencia_);

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('altaEST2',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
 WHEN E_INEX_PARLAMENTO
   THEN
      ROLLBACK;
      rsp :='ERROR: El parlamento no existe';
      altalog ('altaEST2',param_entrada,rsp,rsp2);
   WHEN E_PARLAMENTO_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo idparlamento es nulo, debe informarse';
      altalog ('altaEST2',param_entrada,rsp,rsp2);      
   WHEN E_NOMBRE_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo nombre es nulo, debe informarse';
      altalog ('altaEST2',param_entrada,rsp,rsp2);         
   WHEN E_DIF_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo diferencia es nulo, debe informarse';
      altalog ('altaEST2',param_entrada,rsp,rsp2);      
    
   WHEN E_ANYO_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('altaEST2',param_entrada,rsp,rsp2);      
          
   WHEN OTHERS
   THEN
         ROLLBACK;
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('altaEST2',param_entrada,rsp,rsp2);
END ALTAEST2;
/