create or replace
PROCEDURE ALTAEST5
(
  anyo_ IN EST5.anyo%TYPE, 
  promedio_ IN EST5.promedio%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      ALTAEST5
   PROPSITO:   gestiona el alta de un nuevo registro en la tabla EST5

   PARAMETERS:  anyo_,promedio_, rsp
   INPUT:       anyo_,promedio_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altaEST5('2012','2500',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PROMEDIO_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'anyo_: '||anyo_|| 'promedio_: '||promedio_;

	--verificamos que los campos no nulos no sean nulos
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;
	IF (promedio_ IS NULL) THEN
		RAISE E_PROMEDIO_NUL;
	END IF;  

	INSERT INTO EST5(anyo,promedio) VALUES(anyo_,promedio_);

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('altaEST5',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_ANYO_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('altaEST5',param_entrada,rsp,rsp2);      
   WHEN E_PROMEDIO_NUL
   THEN
         ROLLBACK;
      rsp := 'ERROR: El campo promedio es nulo, debe informarse';
      altalog ('altaEST5',param_entrada,rsp,rsp2);       
   WHEN OTHERS
   THEN
         ROLLBACK;
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('altaEST5',param_entrada,rsp,rsp2);
END ALTAEST5;
/