create or replace
PROCEDURE ALTAEST7
(
  anyo_ IN EST7.anyo%TYPE, 
  nombre_ IN EST7.nombre%TYPE, 
  promedio_ IN EST7.promedio%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      ALTAEST7
   PROPSITO:   gestiona el alta de un nuevo registro en la tabla EST7

   PARAMETERS:  anyo_,nombre_,promedio_, rsp
   INPUT:       anyo_,nombre_,promedio_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altaEST7('2012','Catalan','2500',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PROMEDIO_NUL  EXCEPTION;
E_NOMBRE_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'anyo_: '||anyo_||' nombre_:'||nombre_|| ' promedio_: '||promedio_;

	--verificamos que los campos no nulos no sean nulos
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;
	IF (promedio_ IS NULL) THEN
		RAISE E_PROMEDIO_NUL;
	END IF;  
	IF (nombre_ IS NULL) THEN
		RAISE E_NOMBRE_NUL;
	END IF;    

	INSERT INTO EST7(anyo,nombre,promedio) VALUES(anyo_,nombre_,promedio_);

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('altaEST7',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_ANYO_NUL
   THEN
         ROLLBACK;
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('altaEST7',param_entrada,rsp,rsp2);      
   WHEN E_NOMBRE_NUL
   THEN
         ROLLBACK;
      rsp := 'ERROR: El campo nombre es nulo, debe informarse';
      altalog ('altaEST7',param_entrada,rsp,rsp2);          
   WHEN E_PROMEDIO_NUL
   THEN
         ROLLBACK;
      rsp := 'ERROR: El campo promedio es nulo, debe informarse';
      altalog ('altaEST7',param_entrada,rsp,rsp2);    
   WHEN OTHERS
   THEN
         ROLLBACK;
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('altaEST7',param_entrada,rsp,rsp2);

END ALTAEST7;
/