create or replace
PROCEDURE ALTAEST8
(
  anyo_ IN EST8.anyo%TYPE, 
  total_ IN EST8.total%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      ALTAEST8
   PROPSITO:   gestiona el alta de un nuevo registro en la tabla EST8

   PARAMETERS:  anyo_,total_, rsp
   INPUT:       anyo_,total_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altaEST8('2012','450000',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_TOTAL_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'anyo_: '||anyo_||' total_: '||total_;

	--verificamos que los campos no nulos no sean nulos
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;
	IF (total_ IS NULL) THEN
		RAISE E_TOTAL_NUL;
	END IF;  

	INSERT INTO EST8(anyo,total) VALUES(anyo_,total_);

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('altaEST8',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_ANYO_NUL
   THEN
         ROLLBACK;
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('altaEST8',param_entrada,rsp,rsp2);      
   WHEN E_TOTAL_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo promedio es nulo, debe informarse';
      altalog ('altaEST8',param_entrada,rsp,rsp2);   
 
   WHEN OTHERS
   THEN
         ROLLBACK;
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('altaEST8',param_entrada,rsp,rsp2);
END ALTAEST8;
/