create or replace
PROCEDURE ALTAHGASTOPARLAMENTARIO (
  fecha_ IN historicogastoparlamentario.fecha%TYPE,
  idcategoriagasto_ IN historicogastoparlamentario.IdCategoriaGasto%TYPE,
  idParlamento_ IN historicogastoparlamentario.idParlamento%TYPE,
  idParlamentario_ IN historicogastoparlamentario.idParlamentario%TYPE,
  idPartido_ IN historicogastoparlamentario.idPartido%TYPE,
  importesinIva_ IN historicogastoparlamentario.importesinIva%TYPE,  
  nifEmpresa_ IN historicogastoparlamentario.nifEmpresa%TYPE,  
  descripcionTextual_ IN historicogastoparlamentario.descripcionTextual%TYPE,    
  justificacionTextual_ IN historicogastoparlamentario.justificacionTextual%TYPE,  
  urlInformacion_ IN historicogastoparlamentario.urlInformacion%TYPE,      
  idIva_ IN historicogastoparlamentario.idIva%TYPE,  
  idEstadoGasto_ IN historicogastoparlamentario.idEstadoGasto%TYPE,        
  idFormaPago_ IN historicogastoparlamentario.idFormaPago%TYPE,        
  rsp OUT VARCHAR2  
) is 
/******************************************************************************
   NOMBRE:      ALTAHGASTOPARLAMENTARIO
   PROPSITO:   gestiona el alta de un gasto de un parlamentario

   PARAMETERS:  fecha_,idcategoriagasto_,idParlamento_,idParlamentario_,idPartido_,importesinIva_,nifEmpresa_,descripcionTextual_,urlInformacion_,idIva_,idEstadoGasto_,idFormaPago_,rsp
   INPUT:       fecha_,idcategoriagasto_,idParlamento_,idParlamentario_,idPartido_,importesinIva_,nifEmpresa_,descripcionTextual_,urlInformacion_,idIva_,idEstadoGasto_,idFormaPago_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altahgastoparlamentario('01/10/2013','1','1','1','1','100','B2684043','Gastos de representacion','Por orden del ministro',' ','1','1','1',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_FECHA_NUL  EXCEPTION;
E_CATEGORIA_NUL  EXCEPTION;
E_PARLAMENTO_NUL  EXCEPTION;
E_PARLAMENTARIO_NUL EXCEPTION;
E_PARTIDO_NUL EXCEPTION;
E_IMPORTE_NUL EXCEPTION;
E_DESCRIPCION_NUL EXCEPTION;
E_JUSTIFICACION_NUL EXCEPTION;
E_IVA_NUL EXCEPTION;
E_ESTADO_NUL EXCEPTION;
E_FORMAPAGO_NUL EXCEPTION;

E_INEX_PARLAMENTARIO EXCEPTION;
E_INEX_IVA EXCEPTION;
E_INEX_FORMAPAGO EXCEPTION;
E_INEX_CAT_GASTO EXCEPTION;
E_INEX_EST_GASTO EXCEPTION;

E_NIF_OBLIGA EXCEPTION;

E_DUPLICADO EXCEPTION;
anyo_   NUMBER;
rsp2 VARCHAR2(200);
BEGIN
  	param_entrada:= 'fecha:'||fecha_ ||' idcategoriagasto:'|| idcategoriagasto_ ||
    ' idparlamento: '||idparlamento_||
    ' idparlamentario:'||idparlamentario_ ||' idpartido:'||idpartido_ ||
    ' importesinIva:' || importesinIva_ ||' nifEmpresa:' || nifEmpresa_ ||
    ' descripcionTextual:' ||descripcionTextual_ ||' justificacionTextual:' || justificacionTextual_ ||
    ' urlInformacion:' || urlInformacion_ ||' idIva:' || idIva_|| 
    ' idEstadoGasto:' || idEstadoGasto_ ||' idFormaPago:' ||idFormaPago_;
    

	--verificamos que los campos no nulos no sean nulos
  IF (fecha_ IS NULL) THEN
		RAISE E_FECHA_NUL;  
  ELSIF (idcategoriagasto_ IS NULL) THEN
		RAISE E_CATEGORIA_NUL;    
  ELSIF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;  
  ELSIF (idparlamentario_ IS NULL) THEN
		RAISE E_PARLAMENTARIO_NUL;  
   ELSIF (idpartido_ IS NULL) THEN
		RAISE E_PARTIDO_NUL;  
  ELSIF (importesinIva_ IS NULL) THEN
		RAISE E_IMPORTE_NUL;  
  ELSIF (descripcionTextual_ IS NULL) THEN
		RAISE E_DESCRIPCION_NUL;
  ELSIF (justificacionTextual_ IS NULL) THEN
		RAISE E_JUSTIFICACION_NUL;
  ELSIF (idIva_ IS NULL) THEN
		RAISE E_IVA_NUL;  
  ELSIF (idEstadoGasto_ IS NULL) THEN
		RAISE E_ESTADO_NUL;  
  ELSIF (idFormaPago_ IS NULL) THEN
		RAISE E_FORMAPAGO_NUL;          
	END IF;
  
  
    SELECT COUNT(*) INTO contador 
    FROM GASTOPARLAMENTARIO
    WHERE IDCATEGORIAGASTO=idcategoriagasto_;
    
    IF (contador=0) THEN
      RAISE E_INEX_CAT_GASTO;
    END IF;
    
    
   --Busco en la tabla de parlamentarios si existe un parlamentario con este id y que este asignado a este partido y que no este dado de baja
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTARIO 
    WHERE IDPARLAMENTO=idparlamento_
    AND IDPARLAMENTARIO=idparlamentario_
    AND IDPARTIDO=idpartido_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTARIO;
    END IF;    
  
    --Busco en la tabla de ivas si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM IVA 
    WHERE IDIVA=idiva_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_IVA;
    END IF; 	
    
    
    --Busco en la tabla de estados de gasto si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM ESTADOGASTO
    WHERE IDESTADOGASTO=idestadogasto_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_EST_GASTO;
    END IF;
        
    
    --Busco en la tabla de formas de pago si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM FORMAPAGO 
    WHERE IDFORMAPAGO=idformapago_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_FORMAPAGO;
    END IF; 	    


    --Busco en la tabla de formas de pago de parlamentarios si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM FORMAPAGOPARLAMENTARIO 
    WHERE IDFORMAPAGO=idformapago_;
    
    IF (contador=0) THEN
      RAISE E_INEX_FORMAPAGO;
    END IF; 	    

    --Busco en la tabla de historico de gastos del parlamentario si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM HISTORICOGASTOPARLAMENTARIO 
    WHERE IDPARLAMENTO=idparlamento_
    AND IDPARLAMENTARIO=idparlamentario_
    AND IDPARTIDO = idpartido_
    AND FECHA = fecha_
    AND IDCATEGORIAGASTO = idcategoriagasto_;
    
    IF (contador>0) THEN
      RAISE E_DUPLICADO;
    END IF;
    
   IF ((importesinIva_>30) AND (nifempresa_ IS NULL)) THEN
     RAISE E_NIF_OBLIGA;
   END IF;

  INSERT INTO HISTORICOGASTOPARLAMENTARIO (FECHA,IDCATEGORIAGASTO,IDPARLAMENTO,IDPARLAMENTARIO,IDPARTIDO,IMPORTESINIVA,NIFEMPRESA,
  DESCRIPCIONTEXTUAL,JUSTIFICACIONTEXTUAL,URLINFORMACION,IDIVA,IDESTADOGASTO,IDFORMAPAGO)
  VALUES (fecha_, idcategoriagasto_,idparlamento_,idparlamentario_,idpartido_,importesinIva_,nifempresa_,
  descripciontextual_,justificaciontextual_,urlinformacion_,idiva_,idestadogasto_,idformapago_);
   -- Fin de las operaciones
   rsp := 'OK';
  CALCULAREST1(rsp);
  anyo_ := to_char(fecha_,'yyyy');
  CALCULAREST2(idparlamento_, anyo_,rsp);
  CALCULAREST3(anyo_,rsp);
  CALCULAREST4(rsp);
  CALCULAREST5(anyo_,rsp);
  CALCULAREST6(anyo_,rsp);
  CALCULAREST7(anyo_,rsp);
  CALCULAREST8(anyo_,rsp);
  altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);   
   COMMIT;
EXCEPTION
   WHEN E_PARLAMENTO_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
  WHEN E_PARLAMENTARIO_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo parlamentario es nulo, debe informarse';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
  WHEN E_PARTIDO_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo partido es nulo, debe informarse';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
   WHEN E_FECHA_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo fecha es nulo, debe informarse';
      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);       
   WHEN E_CATEGORIA_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo categoria es nulo, debe informarse';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

   WHEN E_IMPORTE_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo importe es nulo, debe informarse';
 altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

   WHEN E_DESCRIPCION_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo descripcion es nulo, debe informarse';
 altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

   WHEN E_JUSTIFICACION_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo justificacion es nulo, debe informarse';
 altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

   WHEN E_ESTADO_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo estado es nulo, debe informarse';
      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);     
   WHEN E_FORMAPAGO_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo forma de pago es nulo, debe informarse';
      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);               
   WHEN E_IVA_NUL
   THEN
         ROLLBACK;
      rsp :='ERROR: El campo iva es nulo, debe informarse';
      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
  WHEN E_INEX_PARLAMENTARIO
   THEN
      ROLLBACK;   
      rsp :='ERROR: El parlamentario no pertenece al parlamento';
      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
  WHEN E_INEX_CAT_GASTO
   THEN
      ROLLBACK;   
      rsp :='ERROR: No existe la categoria del gasto';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

  WHEN E_INEX_EST_GASTO
   THEN
      ROLLBACK;   
      rsp :='ERROR: No existe estado del gasto';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
  WHEN E_INEX_FORMAPAGO
   THEN
      ROLLBACK;   
      rsp :='ERROR: No existe la forma de pago';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

  WHEN E_INEX_IVA
   THEN
      ROLLBACK;   
      rsp :='ERROR: No existe el tipo de IVA';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);                  
  WHEN E_NIF_OBLIGA
   THEN
      ROLLBACK;   
      rsp :='ERROR: El importe del gasto es superior a 30 euros, el nif de la empresa es obligatorio';
      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
  WHEN E_DUPLICADO
   THEN
         ROLLBACK;
      rsp :='ERROR: Ya existe un gasto del parlamentario con los mismos datos';
       altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);
   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

      altalog ('altaHGastoParlamentario',param_entrada,rsp,rsp2);

END ALTAHGASTOPARLAMENTARIO;
/