create or replace
PROCEDURE ALTAPARLAMENTARIO
(
  id_parlamento IN  parlamentario.idparlamento%TYPE,
  nombre_apellidos IN  parlamentario.nombreapellidos%TYPE,
  id_partido IN parlamentario.idpartido%TYPE,
  rsp OUT VARCHAR2  
) is 
/******************************************************************************
   NOMBRE:      altaParlamentario
   PROPSITO:   gestiona el alta de un parlamentario

   PARAMETERS:  idparlamento,nombreapellidos,idpartido,rsp
   INPUT:       idparlamento,nombreapellidos,idpartido
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altaParlamentario('1','Jose Perez','1',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_NOMBRES_NUL  EXCEPTION;
E_PARTIDO_NUL  EXCEPTION;
E_INEX_PARLAMENTO  EXCEPTION;
E_INEX_PARTIDO  EXCEPTION;
rsp2 VARCHAR2(200);

BEGIN
  	param_entrada:= 'idparlamento: '||id_parlamento||
    'nombreapellidos:'||nombre_apellidos||'idpartido'||id_partido;
    

	--verificamos que los campos no nulos no sean nulos
	IF (id_parlamento IS NULL) THEN
		RAISE E_NUL;  
	END IF;
  
  IF (nombre_apellidos IS NULL) THEN
    RAISE E_NOMBRES_NUL;  
  END IF;
  
  IF (id_partido IS NULL) THEN
    RAISE E_PARTIDO_NUL;  
  END IF;
  
    --Busco en la tabla de parlamentos si existe un parlamento con este id
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO 
    WHERE IDPARLAMENTO=id_parlamento
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;

    --Busco en la tabla de partidos si existe un partido con este id
    SELECT COUNT(*) INTO contador 
    FROM PARTIDO
    WHERE IDPARTIDO=id_partido
     AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARTIDO;
    END IF; 	  
  
  INSERT INTO PARLAMENTARIO (IDPARLAMENTO,IDPARLAMENTARIO,NOMBREAPELLIDOS,IDPARTIDO,FECHABAJA)
  SELECT id_parlamento, nvl(MAX(idparlamentario),0)+1 as idparlamentario, nombre_apellidos,id_partido,NULL
  FROM PARLAMENTARIO
  WHERE IDPARLAMENTO=id_parlamento;
  
  UPDATE PARLAMENTO
  SET NUMEROPARLAMENTARIOS=NUMEROPARLAMENTARIOS+1
  WHERE IDPARLAMENTO=id_parlamento;
  
  
   -- Fin de las operaciones
   
   rsp := 'OK';
altalog ('altaParlamentario',param_entrada,rsp,rsp2);
   COMMIT;

EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo nombre es nulo, debe informarse';
altalog ('altaParlamentario',param_entrada,rsp,rsp2);
  WHEN E_NOMBRES_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo NombreApellidos es nulo, debe informarse';
altalog ('altaParlamentario',param_entrada,rsp,rsp2);

  WHEN E_PARTIDO_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo partido es nulo, debe informarse';
altalog ('altaParlamentario',param_entrada,rsp,rsp2);

  WHEN E_INEX_PARLAMENTO
   THEN
      ROLLBACK;   
      rsp :='ERROR: El Parlamento es inexistente';
altalog ('altaParlamentario',param_entrada,rsp,rsp2);

  WHEN E_INEX_PARTIDO
   THEN
      ROLLBACK;   
      rsp :='ERROR: El Partido es inexistente';
altalog ('altaParlamentario',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
altalog ('altaParlamentario',param_entrada,rsp,rsp2); 
END ALTAPARLAMENTARIO;
/