create or replace
PROCEDURE altaParlamento 
(
  nombre_ IN  parlamento.nombre%TYPE,
  direccionfisica_ IN  parlamento.direccionfisica%TYPE,
  telefono_ IN  parlamento.telefono%TYPE,
  direccionweb_ IN  parlamento.direccionweb%TYPE,
  idestadopais_ IN  parlamento.idestadopais%TYPE,
  idregion_ IN  parlamento.idregion%TYPE,
  rsp OUT VARCHAR2  
) is 
/******************************************************************************
   NOMBRE:      altaParlamento
   PROPSITO:   gestiona el alta de un parlamento

   PARAMETERS:  nombre_,direccionfisica_,telefono_,direccionweb_,idestadopais_,idregion_,rsp
   INPUT:       nombre_,direccionfisica_,telefono_,direccionweb_,idestadopais_,idregion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     altaParlamento('Parlamento Espaol','calle Nogal','913211233','1', '1',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_ESTADOPAIS EXCEPTION;
E_REGION EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
  	param_entrada:= 'nombre: '||nombre_||
    'direccion fisica:'||direccionfisica_ ||' telefono:'||telefono_ ||
    'direccion web:'||direccionweb_ || ' id EstadoPais:'||idestadopais_ ||
    'id region:'||idregion_;
    

	--verificamos que los campos no nulos no sean nulos
  --solo es obligatorio el nombre del parlamento
  --tanto el estadoPais como la region son opcionales
	IF (nombre_ IS NULL) THEN
		RAISE E_NUL;  
	END IF;
  
  IF (idestadopais_ IS NOT NULL) THEN
    --Busco en la tabla de estado pais si existe un estado pais con este id
    SELECT COUNT(*) INTO contador 
    FROM ESTADOPAIS 
    WHERE IDESTADOPAIS=idestadopais_
     AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_ESTADOPAIS;
    END IF;
 	END IF;
  
  IF (idregion_ IS NOT NULL) THEN
    --Busco en la tabla de region si existe una region con este id
    SELECT COUNT(*) INTO contador 
    FROM REGION 
    WHERE IDREGION=idregion_
     AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_REGION;
    END IF;
 	END IF;


  --Por defecto el nmero de parlamentarios es cero
  INSERT INTO PARLAMENTO (NOMBRE,NUMEROPARLAMENTARIOS,DIRECCIONFISICA,TELEFONO,DIRECCIONWEB,IDESTADOPAIS,IDREGION,FECHABAJA)
  VALUES (nombre_,0,direccionfisica_,telefono_,direccionweb_,idestadopais_,idregion_,NULL);
   -- Fin de las operaciones
   rsp := 'OK';
altalog ('altaParlamento',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp :='ERROR: El campo nombre es nulo, debe informarse';
altalog ('altaParlamento',param_entrada,rsp,rsp2);
  WHEN E_ESTADOPAIS
   THEN
      ROLLBACK;   
      rsp :='ERROR: El identificador de estadoPais es errneo';
altalog ('altaParlamento',param_entrada,rsp,rsp2);
  WHEN E_REGION
   THEN
      ROLLBACK;   
      rsp :='ERROR: El identificador de region es errneo';
altalog ('altaParlamento',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
altalog ('altaParlamento',param_entrada,rsp,rsp2);

      
END ALTAPARLAMENTO;
/