create or replace
PROCEDURE BAJESTADO 
(
  idestadopais_ IN ESTADOPAIS.IDESTADOPAIS%TYPE,  
  RSP OUT VARCHAR2  
) IS 
/******************************************************************************
   NOMBRE:      bajEstado
   PROPSITO:   gestiona la baja de un estado

   PARAMETERS:  idestadopais_, rsp
   INPUT:       idestadopais_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajEstado('1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_EXISTE_PARLA  EXCEPTION;
E_EXISTE_ESTADO  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idestadopais: '||idestadopais_;

	--verificamos que los campos no nulos no sean nulos
	IF (idestadopais_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
  
  --buscamos si hay algun parlamento que haga referencia a este estado
   SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO 
    WHERE IDESTADOPAIS=idestadopais_
    AND FECHABAJA IS NULL;
    
    IF(contador>0) THEN
      RAISE E_EXISTE_PARLA;
    END IF;
    
 --buscamos si existe el estado
   SELECT COUNT(*) INTO contador 
    FROM ESTADO 
    WHERE IDESTADOPAIS=idestadopais_;
    
    IF(contador=0) THEN
      RAISE E_EXISTE_ESTADO;
    END IF;    
  
  --Modificamos la fecha de baja del estado pais de las 2 tablas (la de estados y la de estadopais
	UPDATE ESTADOPAIS
  SET FECHABAJA=SYSDATE
  WHERE idEstadoPais=idestadopais_;  

   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('bajEstado',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo idestadopais es nulo, debe informarse';
  altalog ('bajEstado',param_entrada,rsp,rsp2);
   WHEN E_EXISTE_ESTADO
   THEN
      ROLLBACK;   
      rsp := 'ERROR: No existe el estado';
  altalog ('bajEstado',param_entrada,rsp,rsp2);
   WHEN E_EXISTE_PARLA
   THEN
      ROLLBACK;   
      rsp := 'ERROR: Hay un parlamento que hace referencia a este estado';
  altalog ('bajEstado',param_entrada,rsp,rsp2);
   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('bajEstado',param_entrada,rsp,rsp2);
END BAJESTADO;
/