create or replace
PROCEDURE BAJFORMAPAGOPARLAMENTARIO 
(
 idformapago_ IN FORMAPAGO.IDFORMAPAGO%TYPE, 
 RSP OUT VARCHAR2  
)
IS
/******************************************************************************
   NOMBRE:      BAJFORMAPAGOPARLAMENTARIO
   PROPSITO:   gestiona la baja de una forma de pago de parlamentario

   PARAMETERS:  idformapago_, rsp
   INPUT:       idformapago_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajFormaPagoParlamentario('1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_FORMAPAGO EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idformapago: '||idformapago_;

	--verificamos que los campos no nulos no sean nulos
	IF (idformapago_ IS NULL) THEN
		RAISE E_NUL;
	END IF;

  --busco si existe
  SELECT COUNT(*) INTO contador 
    FROM FORMAPAGOPARLAMENTARIO
    WHERE IDFORMAPAGO=idformapago_;
    
    IF (contador=0) THEN
      RAISE E_FORMAPAGO;
    END IF;

  
   --Modificamos la fecha de baja de la forma de pago
	UPDATE FORMAPAGO
  SET FECHABAJA=SYSDATE
  WHERE idformapago=idformapago_;  
  
  

   -- Fin de las operaciones
   rsp := 'OK';

  altalog ('bajFormaPagoParlamentario',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo idformapago es nulo, debe informarse';
  altalog ('bajFormaPagoParlamentario',param_entrada,rsp,rsp2);
   WHEN E_FORMAPAGO
   THEN
      ROLLBACK;  
      rsp := 'ERROR: La forma de pago no existe';
  altalog ('bajFormaPagoParlamentario',param_entrada,rsp,rsp2);
  

   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('bajFormaPagoParlamentario',param_entrada,rsp,rsp2);

END BAJFORMAPAGOPARLAMENTARIO;
/