create or replace
PROCEDURE BAJHGASTOPARLAMENTARIO
(
  fecha_ IN historicogastoparlamentario.fecha%TYPE,
  idcategoriagasto_ IN historicogastoparlamentario.IdCategoriaGasto%TYPE,
  idParlamentario_ IN historicogastoparlamentario.idParlamentario%TYPE,
  idParlamento_ IN historicogastoparlamentario.idParlamento%TYPE,
  RSP OUT VARCHAR2  
) IS 
/******************************************************************************
   NOMBRE:      bajhgaparlamentario
   PROPSITO:   gestiona la baja de un historico de parlamentario

   PARAMETERS:  fecha_,idcategoriagasto_,idparlamento_,idparlamentario_, rsp
   INPUT:       fecha_,idcategoriagasto_,idparlamento_,idparlamentario_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajhgaparlamentario('10/11/2012','1','30','1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_EXISTE_HGPARLA EXCEPTION;
anyo_   NUMBER;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'fecha:'||fecha_||' idcategoriagasto_:'||idcategoriagasto_||' idparlamento: '||idparlamento_||
                  'idparlamentario:'||idparlamentario_;

	--verificamos que los campos no nulos no sean nulos
	IF (idparlamento_ IS NULL OR fecha_ IS NULL OR  idparlamento_ IS NULL OR  idparlamentario_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
      
  --buscamos si existe
   SELECT COUNT(*) INTO contador 
    FROM HISTORICOGASTOPARLAMENTARIO
    WHERE IDPARLAMENTO=idparlamento_    
  AND idcategoriagasto=idcategoriagasto_
  AND fecha = fecha_
  AND idparlamentario=idparlamentario_;
    
    IF(contador=0) THEN
      RAISE E_EXISTE_HGPARLA;
    END IF;
    
  
  --Eliminamos el gasto historico del parlamentario
	DELETE FROM historicogastoparlamentario
  WHERE IDPARLAMENTO=idparlamento_
  AND idcategoriagasto=idcategoriagasto_
  AND fecha = fecha_
  AND idparlamentario=idparlamentario_;

   -- Fin de las operaciones
   rsp := 'OK';
  CALCULAREST1(rsp);
  anyo_ := to_char(fecha_,'yyyy');
  CALCULAREST2(idparlamento_, anyo_,rsp);
  CALCULAREST3(anyo_,rsp);
  CALCULAREST4(rsp);
  CALCULAREST5(anyo_,rsp);
  CALCULAREST6(anyo_,rsp);
  CALCULAREST7(anyo_,rsp);
  CALCULAREST8(anyo_,rsp);
      
  altalog ('bajHGastoParlamentario',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo idcategoriagasto es nulo o el idparlamento es nulo  o la fecha es nula o el idparlamentario, debe informarse';
  altalog ('bajHGastoParlamentario',param_entrada,rsp,rsp2);

   WHEN E_EXISTE_HGPARLA
    THEN
      ROLLBACK;    
      rsp := 'ERROR: No existe el historico del gasto del parlamentario';
  altalog ('bajHGastoParlamentario',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('bajHGastoParlamentario',param_entrada,rsp,rsp2);

END BAJHGASTOPARLAMENTARIO;
/