create or replace
PROCEDURE BAJHGASTOPARLAMENTO
(
  fecha_ IN historicogastoparlamentario.fecha%TYPE,
  idcategoriagasto_ IN historicogastoparlamentario.IdCategoriaGasto%TYPE,
  idParlamento_ IN historicogastoparlamentario.idParlamento%TYPE,
  RSP OUT VARCHAR2  
) IS 
/******************************************************************************
   NOMBRE:      bajhgaparlamento
   PROPSITO:   gestiona la baja de un historico de parlamento

   PARAMETERS:  fecha_,idcategoriagasto_,idparlamento_, rsp
   INPUT:       fecha_,idcategoriagasto_,idparlamento_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajhgaparlamento('10/11/2012','1','30', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_EXISTE_HGPARLA EXCEPTION;
rsp2 VARCHAR2(200);
anyo_ NUMBER;
BEGIN
	param_entrada:= 'fecha:'||fecha_||' idcategoriagasto_:'||idcategoriagasto_||' idparlamento: '||idparlamento_;

	--verificamos que los campos no nulos no sean nulos
	IF (idparlamento_ IS NULL OR fecha_ IS NULL OR  idparlamento_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
      
  --buscamos si existe
   SELECT COUNT(*) INTO contador 
    FROM HISTORICOGASTOPARLAMENTO
    WHERE IDPARLAMENTO=idparlamento_    
  AND idcategoriagasto=idcategoriagasto_
  AND fecha = fecha_;
    
    IF(contador=0) THEN
      RAISE E_EXISTE_HGPARLA;
    END IF;
    
  
  --Eliminamos el gasto historico del parlamento
	DELETE FROM historicogastoparlamento
  WHERE IDPARLAMENTO=idparlamento_
  AND idcategoriagasto=idcategoriagasto_
  AND fecha = fecha_;

   -- Fin de las operaciones
   rsp := 'OK';
  CALCULAREST1(rsp);
   anyo_ := to_char(fecha_,'yyyy');
   CALCULAREST3(anyo_,rsp);
   CALCULAREST8(anyo_,rsp);  
  altalog ('bajHGastoParlamento',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo idcategoriagasto es nulo o el idparlamento es nulo  o la fecha es nula, debe informarse';
  altalog ('bajHGastoParlamento',param_entrada,rsp,rsp2);
   WHEN E_EXISTE_HGPARLA
    THEN
      ROLLBACK;    
      rsp := 'ERROR: No existe el historico del gasto del parlamento';
  altalog ('bajHGastoParlamento',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('bajHGastoParlamento',param_entrada,rsp,rsp2);
END BAJHGASTOPARLAMENTO;
/