create or replace
PROCEDURE BAJIVA
(
  idiva_ IN Iva.idiva%TYPE,  
  rsp OUT VARCHAR2  
) IS
/******************************************************************************
   NOMBRE:      bajiva
   PROPSITO:   gestiona la baja de un tipo de iva

   PARAMETERS:  idiva_, rsp
   INPUT:       idiva_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajiva('1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_IVA EXCEPTION;
rsp2 VARCHAR2(200);

BEGIN
	param_entrada:= 'idiva: '||idiva_;

	--verificamos que los campos no nulos no sean nulos
	IF (idiva_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
  
    --busco si existe
  SELECT COUNT(*) INTO contador 
    FROM iva 
    WHERE idiva=idiva_;
    
    IF (contador=0) THEN
      RAISE E_IVA;
    END IF;
        

   --Modificamos la fecha de baja del IVA
	UPDATE IVA
  SET FECHABAJA=SYSDATE
  WHERE idiva=idiva_;  
   


   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('bajIva',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION

   WHEN E_IVA
   THEN
      ROLLBACK;   
      rsp := 'ERROR: No existe el iva en la tabla de ivas';
  altalog ('bajIva',param_entrada,rsp,rsp2);

   WHEN E_NUL
   THEN
      ROLLBACK;   
      rsp := 'ERROR: El campo idiva es nulo, debe informarse';
  altalog ('bajIva',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('bajIva',param_entrada,rsp,rsp2);

END BAJIVA;
/