create or replace
PROCEDURE BAJPARLAMENTO
(
  idparlamento_ IN PARLAMENTO.idparlamento%TYPE,  
  RSP OUT VARCHAR2  
) IS 
/******************************************************************************
   NOMBRE:      bajparlamento
   PROPSITO:   gestiona la baja de un parlamento

   PARAMETERS:  idparlamento_, rsp
   INPUT:       idparlamento_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajparlamento('1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_EXISTE_PARLA  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idparlamento: '||idparlamento_;

	--verificamos que los campos no nulos no sean nulos
	IF (idparlamento_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
      
  
    
 --buscamos si existe el parlamento
   SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO
    WHERE IDPARLAMENTO=idparlamento_
     AND FECHABAJA IS NULL;
    
    IF(contador=0) THEN
      RAISE E_EXISTE_PARLA;
    END IF;    
  
  
  
    --Modificamos la fecha de baja del parlamentario
	UPDATE PARLAMENTO
  SET FECHABAJA=SYSDATE
  WHERE IDPARLAMENTO=idparlamento_;

   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('bajParlamento',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;      
      rsp := 'ERROR: El campo idparlamentario es nulo o el idparlamento es nulo, debe informarse';
  altalog ('bajParlamento',param_entrada,rsp,rsp2);
   WHEN E_EXISTE_PARLA
   THEN
      ROLLBACK;      
      rsp := 'ERROR: No existe el parlamento';
  altalog ('bajParlamento',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;      
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('bajParlamento',param_entrada,rsp,rsp2);

END BAJPARLAMENTO;
/