create or replace
PROCEDURE BAJPARTIDO
(
  idpartido_ IN PARTIDO.idpartido%TYPE,  
  RSP OUT VARCHAR2  
) IS 
/******************************************************************************
   NOMBRE:      bajpartido
   PROPSITO:   gestiona la baja de un partido

   PARAMETERS:  idpartido_, rsp
   INPUT:       idpartido_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajpartido('1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_EXISTE_PARLA  EXCEPTION;
E_EXISTE_PARTIDO  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idpartido: '||idpartido_;

	--verificamos que los campos no nulos no sean nulos
	IF (idpartido_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
  
  --buscamos si hay algun parlamentario que haga referencia a este partido
   SELECT COUNT(*) INTO contador 
    FROM PARLAMENTARIO 
    WHERE IDPARTIDO=idpartido_
     AND FECHABAJA IS NULL;
    
    IF(contador>0) THEN
      RAISE E_EXISTE_PARLA;
    END IF;
    
  
    
 --buscamos si existe el partido
   SELECT COUNT(*) INTO contador 
    FROM PARTIDO
    WHERE IDPARTIDO=idpartido_
     AND FECHABAJA IS NULL;
    
    IF(contador=0) THEN
      RAISE E_EXISTE_PARTIDO;
    END IF;    
  

  
   --Modificamos la fecha de baja del Partido
	UPDATE PARTIDO
  SET FECHABAJA=SYSDATE
  WHERE idpartido=idpartido_;

   -- Fin de las operaciones
   rsp := 'OK';

  altalog ('bajPartido',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;      
      rsp := 'ERROR: El campo idpartido es nulo, debe informarse';
  altalog ('bajPartido',param_entrada,rsp,rsp2);

   WHEN E_EXISTE_PARTIDO
   THEN
      ROLLBACK;      
      rsp := 'ERROR: No existe el partido';
  altalog ('bajPartido',param_entrada,rsp,rsp2);

   WHEN E_EXISTE_PARLA
   THEN
      ROLLBACK;      
      rsp := 'ERROR: Hay un parlamentario que hace referencia a este partido';
  altalog ('bajPartido',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;      
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('bajPartido',param_entrada,rsp,rsp2);

END BAJPARTIDO;
/