create or replace
PROCEDURE BAJREGION
(
  idregion_ IN REGION.idregion%TYPE,  
  RSP OUT VARCHAR2  
) IS 
/******************************************************************************
   NOMBRE:      bajregion
   PROPSITO:   gestiona la baja de una region

   PARAMETERS:  idregion_, rsp
   INPUT:       idregion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     bajregion('1', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_EXISTE_PARLA  EXCEPTION;
E_EXISTE_REGION  EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idregion: '||idregion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idregion_ IS NULL) THEN
		RAISE E_NUL;
	END IF;
  
  --buscamos si hay algun parlamento que haga referencia a esta region
   SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO 
    WHERE IDREGION=idregion_
     AND FECHABAJA IS NULL;
    
    IF(contador>0) THEN
      RAISE E_EXISTE_PARLA;
    END IF;
    
 --buscamos si existe la region
   SELECT COUNT(*) INTO contador 
    FROM REGION
    WHERE IDREGION=idregion_
     AND FECHABAJA IS NULL;
    
    IF(contador=0) THEN
      RAISE E_EXISTE_REGION;
    END IF;    
  
  --Modificamos la fecha de baja de la Region
	UPDATE REGION
  SET FECHABAJA=SYSDATE
  WHERE idregion=idregion_;


   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('bajRegion',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_NUL
   THEN
      ROLLBACK;      
      rsp := 'ERROR: El campo idestadopais es nulo, debe informarse';
  altalog ('bajRegion',param_entrada,rsp,rsp2);

   WHEN E_EXISTE_REGION
   THEN
      ROLLBACK;      
      rsp := 'ERROR: No existe la region';
  altalog ('bajRegion',param_entrada,rsp,rsp2);

   WHEN E_EXISTE_PARLA
   THEN
      ROLLBACK;      
      rsp := 'ERROR: Hay un parlamento que hace referencia a esta region';
  altalog ('bajRegion',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
      ROLLBACK;      
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('bajRegion',param_entrada,rsp,rsp2);

END BAJREGION;
/