create or replace
PROCEDURE MODEST4
(
  idParlamento_ IN EST4.idParlamento%TYPE, 
  idParlamentario_ IN EST4.idParlamentario%TYPE, 
  nombreApellidos_ IN EST4.nombreApellidos%TYPE,
  gastoTotal_ IN EST4.gastoTotal%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      MODEST4
   PROPSITO:   gestiona la modificacin de un registro en la tabla EST4

   PARAMETERS:  idParlamento_,idParlamentario_,nombreApellidos_,gastoTotal_, rsp
   INPUT:       idParlamento_,idParlamentario_,nombreApellidos_,gastoTotal_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modEST4('1','1','Joan Constantino','18000',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PARLAMENTO_NUL  EXCEPTION;
E_PARLAMENTARIO_NUL  EXCEPTION;
E_NOMBRE_NUL  EXCEPTION;
E_GASTO_NUL  EXCEPTION;
contador      INTEGER;
E_INEX_PARLAMENTARIO EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idParlamento_: '||idparlamento_|| 'idParlamentario_: '||idparlamentario_||' nombreApellidos_: '||nombreApellidos_||
    'gastoTotal_: '||gastoTotal_;

	--verificamos que los campos no nulos no sean nulos
	IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;
	END IF;
	IF (idparlamentario_ IS NULL) THEN
		RAISE E_PARLAMENTARIO_NUL;
	END IF;  
	IF (nombreApellidos_ IS NULL) THEN
		RAISE E_NOMBRE_NUL;
	END IF;  
	IF (gastoTotal_ IS NULL) THEN
		RAISE E_GASTO_NUL;
	END IF;
  
--Busco en la tabla de parlamentarios si existe un parlamentario con este id
    SELECT COUNT(*) INTO contador 
    FROM EST4
    WHERE IDPARLAMENTO=idparlamento_
    AND IDPARLAMENTARIO=idparlamentario_;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTARIO;
    END IF;  
    
    
	UPDATE EST4
  SET nombreApellidos=nombreApellidos_,
  gastoTotal = gastoTotal_
  WHERE idparlamento=idparlamento_
  AND idparlamentario=idparlamentario_;

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('modEST4',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
  WHEN E_INEX_PARLAMENTARIO
   THEN
   ROLLBACK;   
      rsp :='ERROR: Registro inexistente';
      altalog ('modEST4',param_entrada,rsp,rsp2);
   WHEN E_PARLAMENTO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idparlamento es nulo, debe informarse';
      altalog ('modEST4',param_entrada,rsp,rsp2);

   WHEN E_PARLAMENTARIO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idparlamentario es nulo, debe informarse';
      altalog ('modEST4',param_entrada,rsp,rsp2);

   WHEN E_NOMBRE_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo nombreApellidos es nulo, debe informarse';
      altalog ('modEST4',param_entrada,rsp,rsp2);

   WHEN E_GASTO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo gasto es nulo, debe informarse';
      altalog ('modEST4',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('modEST4',param_entrada,rsp,rsp2);

END MODEST4;
/