create or replace
PROCEDURE MODEST5
(
  anyo_ IN EST5.anyo%TYPE, 
  promedio_ IN EST5.promedio%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      modEST5
   PROPSITO:   gestiona la modificacin de un registro en la tabla EST5

   PARAMETERS:  anyo_,promedio_, rsp
   INPUT:       anyo_,promedio_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modEST5('2012','2500',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PROMEDIO_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
contador      INTEGER;
E_INEX_PARLAMENTO EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'anyo_: '||anyo_|| 'promedio_: '||promedio_;

	--verificamos que los campos no nulos no sean nulos
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;
	IF (promedio_ IS NULL) THEN
		RAISE E_PROMEDIO_NUL;
	END IF;  

--Busco en la tabla de EST5 si existe un registro igual
    SELECT COUNT(*) INTO contador 
    FROM EST5
    WHERE ANYO=anyo_;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;  
    
    
  UPDATE EST5
  set promedio=promedio_
  where anyo=anyo_;

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('modEST5',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
 WHEN E_INEX_PARLAMENTO
   THEN
   ROLLBACK;   
      rsp :='ERROR: No existe el registro';
      altalog ('modEST5',param_entrada,rsp,rsp2);
   WHEN E_ANYO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('modEST5',param_entrada,rsp,rsp2);      
   WHEN E_PROMEDIO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo promedio es nulo, debe informarse';
      altalog ('modEST5',param_entrada,rsp,rsp2);   
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('modEST5',param_entrada,rsp,rsp2);
END MODEST5;
/