create or replace
PROCEDURE MODEST6
(
  anyo_ IN EST6.anyo%TYPE,
  idParlamentarioMas_ IN EST6.idParlamentarioMas%TYPE, 
  nParlamentarioMas_ IN EST6.nParlamentarioMas%TYPE, 
  importeMas_ IN EST6.importeMas%TYPE, 
  idParlamentarioMen_ IN EST6.idParlamentarioMen%TYPE, 
  nParlamentarioMen_ IN EST6.nParlamentarioMen%TYPE, 
  importeMen_ IN EST6.importeMen%TYPE,   
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      MODEST6
   PROPSITO:   gestiona el alta de un nuevo registro en la tabla EST6

   PARAMETERS:  anyo_,idParlamentarioMas_,nParlamentarioMas_,importeMas_,idParlamentarioMen_,nParlamentarioMen_,importeMen_, rsp
   INPUT:       anyo_,idParlamentarioMas_,nParlamentarioMas_,importeMas_,idParlamentarioMen_,nParlamentarioMen_,importeMen_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modEST6('2012','1','Jose Mota',10000,'30','Carlos Gonzalez','100',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PARLAMENTARIO_NUL  EXCEPTION;
E_NOMBRE_NUL  EXCEPTION;
E_IMPORTE_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
contador      INTEGER;
E_INEX_PARLAMENTO EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'anyo_:'||anyo_||'idParlamentarioMas_: '||idParlamentarioMas_||' nParlamentarioMas_: '||nParlamentarioMas_||'importeMas_: '||importeMas_||' idParlamentarioMen_:'||idParlamentarioMen_||
    ' nParlamentarioMen_:'||nParlamentarioMen_||'importeMen_: '||importeMen_;

	--verificamos que los campos no nulos no sean nulos
	IF (idParlamentarioMas_ IS NULL OR idParlamentarioMen_ IS NULL) THEN
		RAISE E_PARLAMENTARIO_NUL;
	END IF;
	IF (nParlamentarioMas_ IS NULL OR nParlamentarioMen_ IS NULL) THEN
		RAISE E_NOMBRE_NUL;
	END IF;  
	IF (importeMas_ IS NULL OR importeMen_ IS NULL) THEN
		RAISE E_IMPORTE_NUL;
	END IF;
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;	 
  
  --Busco en la tabla de EST6 si existe un registro igual
    SELECT COUNT(*) INTO contador 
    FROM EST6
    WHERE ANYO=anyo_;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;  
    
  UPDATE EST6
  SET idParlamentarioMas=idParlamentarioMas_,
  nParlamentarioMas=nParlamentarioMas_,
  importeMas=importeMas_,
  idParlamentarioMen=idParlamentarioMen_,
  nParlamentarioMen=nParlamentarioMen_,
  importeMen=importeMen_
  WHERE anyo=anyo_;
  
   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modEST6',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
  WHEN E_INEX_PARLAMENTO
   THEN
   ROLLBACK;   
      rsp :='ERROR: No existe el registro';
      altalog ('modEST6',param_entrada,rsp,rsp2);
   WHEN E_PARLAMENTARIO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idparlamentoMas o idparlamentarioMen es nulo, debe informarse';
      altalog ('modEST6',param_entrada,rsp,rsp2);
   WHEN E_NOMBRE_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo nparlamentarioMas o nparlamentarioMen es nulo, debe informarse';
      altalog ('modEST6',param_entrada,rsp,rsp2);
   WHEN E_IMPORTE_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo importeMas o importeMen es nulo, debe informarse';
      altalog ('modEST6',param_entrada,rsp,rsp2);      
   WHEN E_ANYO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('modEST6',param_entrada,rsp,rsp2);      
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

      altalog ('modEST6',param_entrada,rsp,rsp2);
END MODEST6;
/