create or replace
PROCEDURE MODEST7
(
  anyo_ IN EST7.anyo%TYPE, 
  nombre_ IN EST7.nombre%TYPE, 
  promedio_ IN EST7.promedio%TYPE,
  RSP OUT VARCHAR2
)
IS

/******************************************************************************
   NOMBRE:      MODEST7
   PROPSITO:   gestiona el alta de un nuevo registro en la tabla EST7

   PARAMETERS:  anyo_,nombre_,promedio_, rsp
   INPUT:       anyo_,nombre_,promedio_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modEST7('2012','Catalan','2500',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
E_PROMEDIO_NUL  EXCEPTION;
E_NOMBRE_NUL  EXCEPTION;
E_ANYO_NUL  EXCEPTION;
contador      INTEGER;
E_INEX_PARLAMENTO EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'anyo_: '||anyo_||' nombre_:'||nombre_|| ' promedio_: '||promedio_;

	--verificamos que los campos no nulos no sean nulos
	IF (anyo_ IS NULL) THEN
		RAISE E_ANYO_NUL;
	END IF;
	IF (promedio_ IS NULL) THEN
		RAISE E_PROMEDIO_NUL;
	END IF;  
	IF (nombre_ IS NULL) THEN
		RAISE E_NOMBRE_NUL;
	END IF;    
  
  --Busco en la tabla de EST7 si existe un registro igual
    SELECT COUNT(*) INTO contador 
    FROM EST7
    WHERE ANYO=anyo_;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;  

  UPDATE EST7
  SET nombre=nombre_,
  promedio=promedio_
  WHERE anyo=anyo_;

   -- Fin de las operaciones
   rsp := 'OK';
altalog ('modEST7',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
WHEN E_INEX_PARLAMENTO
   THEN
   ROLLBACK;   
      rsp :='ERROR: No existe el registro';
      altalog ('modEST8',param_entrada,rsp,rsp2);
   WHEN E_ANYO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo anyo es nulo, debe informarse';
      altalog ('modEST7',param_entrada,rsp,rsp2);      
   WHEN E_NOMBRE_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo nombre es nulo, debe informarse';
      altalog ('modEST7',param_entrada,rsp,rsp2);   
   WHEN E_PROMEDIO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo promedio es nulo, debe informarse';
      altalog ('modEST7',param_entrada,rsp,rsp2);   
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

altalog ('modEST7',param_entrada,rsp,rsp2);

END MODEST7;
/