create or replace
PROCEDURE MODLOG (
   idlog_           IN logs.idlog%TYPE, 
   procedimiento_   IN LOGS.procedimiento%TYPE, 
   parentrada_      IN LOGS.parentrada%TYPE, 
   parsalida_       IN LOGS.parsalida%TYPE,
   rsp              OUT VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modLog
   PROPSITO:   gestiona la modificacin en la tabla log
                
   PARAMETERS:  idLog_,procedimiento_, parentrada_, parsalida_,rsp
   INPUT:       idLog_,procedimiento_, parentrada_, parsalida_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa, 'ERROR: Tipo de Error' en
                caso contrario
   EJEMPLO DE USO:     modLog('1500','altaEstado', 'descripcion:Francia','ok', rst)
******************************************************************************/
  
   E_NUL             EXCEPTION;
BEGIN
 

   --verificamos que los campos no nulos no sean nulos
   IF ((procedimiento_ IS NULL) OR (parentrada_ IS NULL) OR (parsalida_ IS NULL) ) THEN 
        RAISE E_NUL;
   END IF; 

   -- insertamos el nuevo log
   UPDATE LOGS
   SET FECHA=SYSDATE,
   PROCEDIMIENTO=procedimiento_,
   PARENTRADA=parentrada_,
   PARSALIDA=parsalida_
   WHERE IDLOG = idlog_;
   
   -- Fin de las operaciones
   rsp := 'OK';
   COMMIT;
EXCEPTION
 WHEN E_NUL
   THEN
      rsp := 'ERROR: Hay un campo nulo al acceder a log, debe informarse';

      ROLLBACK;
WHEN OTHERS
   THEN
      rsp :=    'ERROR:'||SUBSTR (SQLERRM, 1, 100);
      ROLLBACK;
END MODLOG;
/