create or replace
PROCEDURE modEstadoGasto (   
   idEstadoGasto_     IN    EstadoGasto.idEstadoGasto%TYPE,
   descripcion_ 	    IN    EstadoGasto.descripcion%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modEstadoGasto
   PROPSITO:   gestiona la modificacion de la descripcion de un Estado de gasto

   PARAMETERS:  idEstadoGasto_,descripcion_, rsp   
   INPUT:       idEstadoGasto_,descripcion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modEstadoGasto('1','Aprobado', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_ESTADO_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_ESTADO   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idEstadoGasto:'||idEstadoGasto_||' descripcion: '||descripcion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idEstadoGasto_ IS NULL) THEN
		RAISE E_ESTADO_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;

 --Busco en la tabla de Estado de gastos si existe un estado de gasto con este id
    SELECT COUNT(*) INTO contador 
    FROM ESTADOGASTO 
    WHERE IDESTADOGASTO=idEstadoGasto_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_ESTADO;
    END IF;
    
	 
	UPDATE ESTADOGASTO
  set descripcion = descripcion_
  WHERE IDESTADOGASTO = idEstadoGasto_;


   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modEstadoGasto',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_ESTADO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idestadogasto es nulo, debe informarse';
  altalog ('modEstadoGasto',param_entrada,rsp,rsp2);
   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modEstadoGasto',param_entrada,rsp,rsp2);

   WHEN E_ESTADO
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de estado de gasto con este identificador';
  altalog ('modEstadoGasto',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('modEstadoGasto',param_entrada,rsp,rsp2);

END modEstadoGasto;
/