create or replace
PROCEDURE modEstadoPais (   
   idEstadoPais_     IN    ESTADOPAIS.idestadopais%TYPE,
   descripcion_ 	    IN    ESTADOPAIS.descripcion%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modEstadoPais
   PROPSITO:   gestiona la modificacion de un estado Pais

   PARAMETERS:  idEstadoPais_,descripcion_, rsp
   INPUT:       idEstadoPais_,descripcion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modEstadoPais('1','Alemania', rsp)   
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_ESTADO_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_ESTADOPAIS   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idEstadoPais:'||idEstadoPais_||' descripcion: '||descripcion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idEstadoPais_ IS NULL) THEN
		RAISE E_ESTADO_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;

 --Busco en la tabla de estado pais si existe un estado pais con este id
    SELECT COUNT(*) INTO contador 
    FROM ESTADOPAIS 
    WHERE IDESTADOPAIS=idEstadoPais_
     AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_ESTADOPAIS;
    END IF;
    
	 
	UPDATE ESTADOPAIS
  set descripcion = descripcion_
  WHERE idEstadoPais = idEstadoPais_;


   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modEstadoPais',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_ESTADO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idestadopais es nulo, debe informarse';
  altalog ('modEstadoPais',param_entrada,rsp,rsp2);

   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modEstadoPais',param_entrada,rsp,rsp2);
   WHEN E_ESTADOPAIS
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de EstadoPais con este identificador';
  altalog ('modEstadoPais',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('modEstadoPais',param_entrada,rsp,rsp2);

END modEstadoPais;
/