create or replace
PROCEDURE modFormaPago (   
   idFormaPago_     IN    formapago.idformapago%TYPE,
   descripcion_ 	  IN    formapago.descripcion%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modFormaGasto
   PROPSITO:   gestiona la modificacion de la descripcion de una forma de pago

   PARAMETERS:  idFormaPago_,descripcion_, rsp
   INPUT:       idFormaPago_,descripcion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modFormaPago('1','Visa', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_FORMA_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_FORMA   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idFormaPago:'||idFormaPago_||' descripcion: '||descripcion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idFormaPago_ IS NULL) THEN
		RAISE E_FORMA_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;

 --Busco en la tabla de Formas de pago si existe una forma de pago con este id
    SELECT COUNT(*) INTO contador 
    FROM FORMAPAGO 
    WHERE IDFORMAPAGO=idFormaPago_
     AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_FORMA;
    END IF;
    
	 
	UPDATE FORMAPAGO
  set descripcion = descripcion_
  WHERE IDFORMAPAGO = idFormaPago_;

   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modFormaPago',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_FORMA_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idformapago es nulo, debe informarse';
  altalog ('modFormaPago',param_entrada,rsp,rsp2);

   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modFormaPago',param_entrada,rsp,rsp2);

   WHEN E_FORMA
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de forma de pago con este identificador';
  altalog ('modFormaPago',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('modFormaPago',param_entrada,rsp,rsp2);

END modFormaPago;
/