create or replace
PROCEDURE modGasto (   
   idCategoriaGasto_     IN    GASTO.idCategoriaGasto%TYPE,
   descripcion_ 	    IN    GASTO.descripcion%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modGasto
   PROPSITO:   gestiona la modificacion de la descripcion de un gasto

   PARAMETERS:  idCategoriaGasto_,descripcion_, rsp
   INPUT:       idCategoriaGasto_,descripcion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modGasto('1','Gasto alcaldia', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_CAT_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_GASTO   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idCategoriaGasto:'||idCategoriaGasto_||' descripcion: '||descripcion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idCategoriaGasto_ IS NULL) THEN
		RAISE E_CAT_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;

 --Busco en la tabla de gastos si existe un gasto con este id
    SELECT COUNT(*) INTO contador 
    FROM GASTO 
    WHERE IDCATEGORIAGASTO=idCategoriaGasto_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_GASTO;
    END IF;

    
	 
	UPDATE GASTO
  set descripcion = descripcion_
  WHERE IDCATEGORIAGASTO = idCategoriaGasto_;


   -- Fin de las operaciones
   rsp := 'OK';

  altalog ('modGasto',param_entrada,rsp,rsp2);
   COMMIT;
EXCEPTION
   WHEN E_CAT_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idcategoriagasto es nulo, debe informarse';
  altalog ('modGasto',param_entrada,rsp,rsp2);

   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modGasto',param_entrada,rsp,rsp2);

   WHEN E_GASTO
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de gasto con este identificador';
  altalog ('modGasto',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('modGasto',param_entrada,rsp,rsp2);

END modGasto;
/