create or replace
PROCEDURE MODHGASTOPARLAMENTO (
  fecha_ IN historicogastoparlamentario.fecha%TYPE,
  idcategoriagasto_ IN historicogastoparlamentario.IdCategoriaGasto%TYPE,
  idParlamento_ IN historicogastoparlamentario.idParlamento%TYPE,
  importesinIva_ IN historicogastoparlamentario.importesinIva%TYPE,  
  nifEmpresa_ IN historicogastoparlamentario.nifEmpresa%TYPE,  
  descripcionTextual_ IN historicogastoparlamentario.descripcionTextual%TYPE,    
  justificacionTextual_ IN historicogastoparlamentario.justificacionTextual%TYPE,  
  urlInformacion_ IN historicogastoparlamentario.urlInformacion%TYPE,      
  idIva_ IN historicogastoparlamentario.idIva%TYPE,  
  idEstadoGasto_ IN historicogastoparlamentario.idEstadoGasto%TYPE,        
  idFormaPago_ IN historicogastoparlamentario.idFormaPago%TYPE,        
  rsp OUT VARCHAR2  
) is 
/******************************************************************************
   NOMBRE:      MODHGASTOPARLAMENTO
   PROPSITO:   gestiona la modificacin de un gasto de un parlamento

   PARAMETERS:  fecha_,idcategoriagasto_,idParlamento_,importesinIva_,nifEmpresa_,descripcionTextual_,urlInformacion_,idIva_,idEstadoGasto_,idFormaPago_,rsp
   INPUT:       fecha_,idcategoriagasto_,idParlamento_,importesinIva_,nifEmpresa_,descripcionTextual_,urlInformacion_,idIva_,idEstadoGasto_,idFormaPago_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modhgastoparlamento('01/10/2013','1','1','100','B2684043','Gastos de representacion','Por orden del ministro',' ','1','1','1',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_FECHA_NUL  EXCEPTION;
E_CATEGORIA_NUL  EXCEPTION;
E_PARLAMENTO_NUL  EXCEPTION;
E_IMPORTE_NUL EXCEPTION;
E_DESCRIPCION_NUL EXCEPTION;
E_JUSTIFICACION_NUL EXCEPTION;
E_IVA_NUL EXCEPTION;
E_ESTADO_NUL EXCEPTION;
E_FORMAPAGO_NUL EXCEPTION;

E_INEX_PARLAMENTO EXCEPTION;
E_INEX_IVA EXCEPTION;
E_INEX_FORMAPAGO EXCEPTION;
E_INEX_CAT_GASTO EXCEPTION;
E_INEX_EST_GASTO EXCEPTION;
E_NIF_OBLIGA EXCEPTION;

E_INEX EXCEPTION;
anyo_ NUMBER;
rsp2 VARCHAR2(200);
BEGIN
  	param_entrada:= 'fecha:'||fecha_ ||' idcategoriagasto:'|| idcategoriagasto_ ||
    ' idparlamento: '||idparlamento_||  
    ' importesinIva:' || importesinIva_ ||' nifEmpresa:' || nifEmpresa_ ||
    ' descripcionTextual:' ||descripcionTextual_ ||' justificacionTextual:' || justificacionTextual_ ||
    ' urlInformacion:' || urlInformacion_ ||' idIva:' || idIva_|| 
    ' idEstadoGasto:' || idEstadoGasto_ ||' idFormaPago:' ||idFormaPago_;
    

	--verificamos que los campos no nulos no sean nulos
  IF (fecha_ IS NULL) THEN
		RAISE E_FECHA_NUL;  
  ELSIF (idcategoriagasto_ IS NULL) THEN
		RAISE E_CATEGORIA_NUL;    
  ELSIF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;  
  ELSIF (importesinIva_ IS NULL) THEN
		RAISE E_IMPORTE_NUL;  
  ELSIF (descripcionTextual_ IS NULL) THEN
		RAISE E_DESCRIPCION_NUL;
  ELSIF (justificacionTextual_ IS NULL) THEN
		RAISE E_JUSTIFICACION_NUL;
  ELSIF (idIva_ IS NULL) THEN
		RAISE E_IVA_NUL;  
  ELSIF (idEstadoGasto_ IS NULL) THEN
		RAISE E_ESTADO_NUL;  
  ELSIF (idFormaPago_ IS NULL) THEN
		RAISE E_FORMAPAGO_NUL;          
	END IF;


    SELECT COUNT(*) INTO contador 
    FROM GASTO
    WHERE IDCATEGORIAGASTO=idcategoriagasto_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_CAT_GASTO;
    END IF;


    SELECT COUNT(*) INTO contador 
    FROM GASTOPARLAMENTO
    WHERE IDCATEGORIAGASTO=idcategoriagasto_;
    
    IF (contador=0) THEN
      RAISE E_INEX_CAT_GASTO;
    END IF;

  
   --Busco en la tabla de parlamentos si existe un parlamento con este id
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO
    WHERE IDPARLAMENTO=idparlamento_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;
    
  
    --Busco en la tabla de ivas si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM IVA 
    WHERE IDIVA=idiva_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_IVA;
    END IF; 	
    
    
    SELECT COUNT(*) INTO contador 
    FROM ESTADOGASTO
    WHERE IDESTADOGASTO=idestadogasto_
    AND FECHABAJA IS NULL;
    
    
    IF (contador=0) THEN
      RAISE E_INEX_EST_GASTO;
    END IF;
    
    --Busco en la tabla de formas de pago si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM FORMAPAGO 
    WHERE IDFORMAPAGO=idformapago_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_INEX_FORMAPAGO;
    END IF; 	    
    

    --Busco en la tabla de formas de pago de parlamento si existe un registro con los mismos datos
    SELECT COUNT(*) INTO contador 
    FROM FORMAPAGOPARLAMENTO 
    WHERE IDFORMAPAGO=idformapago_;
    
    IF (contador=0) THEN
      RAISE E_INEX_FORMAPAGO;
    END IF; 	    

    SELECT COUNT(*) INTO contador 
    FROM HISTORICOGASTOPARLAMENTO
    WHERE IDPARLAMENTO=idparlamento_
    AND FECHA = fecha_
    AND IDCATEGORIAGASTO = idcategoriagasto_;
    
    IF (contador=0) THEN
      RAISE E_INEX;
    END IF;
    
    
   IF ((importesinIva_>30) AND (nifempresa_ IS NULL)) THEN
     RAISE E_NIF_OBLIGA;
   END IF;

  UPDATE HISTORICOGASTOPARLAMENTO 
  SET IMPORTESINIVA=importesinIva_,
  NIFEMPRESA=nifempresa_,
  DESCRIPCIONTEXTUAL=descripciontextual_,
  JUSTIFICACIONTEXTUAL=justificaciontextual_,
  URLINFORMACION=urlinformacion_,
  IDIVA=idiva_,
  IDESTADOGASTO=idestadogasto_,
  IDFORMAPAGO=idformapago_
  WHERE FECHA=fecha_ AND
  IDCATEGORIAGASTO=idcategoriagasto_ AND
  IDPARLAMENTO=idparlamento_;

   -- Fin de las operaciones
   rsp := 'OK';
  CALCULAREST1(rsp);
   anyo_ := to_char(fecha_,'yyyy');
   CALCULAREST3(anyo_,rsp);
   CALCULAREST8(anyo_,rsp);
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
   COMMIT;   

EXCEPTION

   WHEN E_PARLAMENTO_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
   WHEN E_FECHA_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo fecha es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_CATEGORIA_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo categoria es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_IMPORTE_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo importe es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_DESCRIPCION_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo descripcion es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_JUSTIFICACION_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo justificacion es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_ESTADO_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo estado es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_FORMAPAGO_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo forma de pago es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_IVA_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo iva es nulo, debe informarse';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_INEX_PARLAMENTO
   THEN
   ROLLBACK;   
      rsp :='ERROR: El parlamento no existe';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_INEX_CAT_GASTO
   THEN
      ROLLBACK;
      rsp :='ERROR: No existe la categoria del gasto';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_INEX_EST_GASTO
   THEN
   ROLLBACK;   
      rsp :='ERROR: No existe estado del gasto';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);

  WHEN E_INEX_FORMAPAGO
   THEN
   ROLLBACK;   
      rsp :='ERROR: No existe la forma de pago';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_INEX_IVA
   THEN
   ROLLBACK;   
      rsp :='ERROR: No existe el tipo de IVA';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_NIF_OBLIGA
   THEN
      ROLLBACK;
      rsp :='ERROR: El importe del gasto es superior a 30 euros, el nif de la empresa es obligatorio';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_INEX
   THEN
      ROLLBACK;
      rsp :='ERROR: No existe un gasto del parlamentario con los mismos datos';
  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);

   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('modHGastoParlamento',param_entrada,rsp,rsp2);

END MODHGASTOPARLAMENTO;
/