create or replace
PROCEDURE modIva (   
   idIva_     IN    iva.idiva%TYPE,
   descripcion_ 	  IN   iva.descripcion%TYPE,
   porcentaje_ 	  IN   iva.porcentaje%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modIva
   PROPSITO:   gestiona la modificacion de un tipo de iva

   PARAMETERS:  idva_,descripcion_,porcentaje_, rsp
   INPUT:       idva_,descripcion_,porcentaje_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modIva('1','21%',21, rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_IVA_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_PORCENTAJE_NUL  EXCEPTION;
E_IVA   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idIva:'||idIva_||' descripcion: '||descripcion_||' porcentaje'||porcentaje_;

	--verificamos que los campos no nulos no sean nulos
	IF (idIva_ IS NULL) THEN
		RAISE E_IVA_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;
  
  IF (porcentaje_ IS NULL) THEN
		RAISE E_PORCENTAJE_NUL;
	END IF;
    

 --Busco en la tabla de ivas si existe un iva con este id
    SELECT COUNT(*) INTO contador 
    FROM IVA 
    WHERE IDIVA=idiva_
    AND FECHABAJA IS NULL;

    
    IF (contador=0) THEN
      RAISE E_IVA;
    END IF;
    
	 
	UPDATE IVA
  set descripcion = descripcion_,
    porcentaje = porcentaje_
  WHERE IDIVA = idiva_;


   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modIva',param_entrada,rsp,rsp2);
   COMMIT;   
EXCEPTION
   WHEN E_IVA_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idIva es nulo, debe informarse';
  altalog ('modIva',param_entrada,rsp,rsp2);

   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modIva',param_entrada,rsp,rsp2);
 
   WHEN E_PORCENTAJE_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo porcentaje es nulo, debe informarse';
  altalog ('modIva',param_entrada,rsp,rsp2);
 
   WHEN E_IVA
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de iva con este identificador';
  altalog ('modIva',param_entrada,rsp,rsp2);
 
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('modIva',param_entrada,rsp,rsp2);
 
END modIva;
/