create or replace
PROCEDURE MODPARLAMENTARIO
(
  id_parlamentario IN  parlamentario.idparlamentario%TYPE,
  id_parlamento IN  parlamentario.idparlamento%TYPE,
  nombre_apellidos IN  parlamentario.nombreapellidos%TYPE,
  id_partido IN parlamentario.idpartido%TYPE,
  rsp OUT VARCHAR2  
) is 
/******************************************************************************
   NOMBRE:      modParlamentario
   PROPSITO:   gestiona la modificacin de un parlamentario

   PARAMETERS:  id_parlamentario,id_parlamento,nombre_apellidos,id_partido,rsp
   INPUT:       id_parlamentario,id_parlamento,nombre_apellidos,id_partido
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modParlamentario('1','1','Jose Perez','5',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_PARLAMENTARIO_NUL  EXCEPTION;
E_NUL  EXCEPTION;
E_PARTIDO_NUL  EXCEPTION;
E_NOMBRES_NUL EXCEPTION;
E_INEX_PARLAMENTO  EXCEPTION;
E_INEX_PARTIDO  EXCEPTION;
E_INEX_PARLAMENTARIO EXCEPTION;
rsp2 VARCHAR2(200);

BEGIN
  	param_entrada:= 'idparlamentario:'||id_parlamentario||'idparlamento: '||id_parlamento||
    'nombreapellidos:'||nombre_apellidos || 'idpartido:' ||id_partido;
    

	--verificamos que los campos no nulos no sean nulos
  
  if (id_parlamentario IS NULL)  THEN
    RAISE E_PARLAMENTARIO_NUL;
  END IF;
  
	IF (id_parlamento IS NULL) THEN
		RAISE E_NUL;  
	END IF;
  IF (id_partido IS NULL) THEN
		RAISE E_PARTIDO_NUL;  
	END IF;
  
  IF (nombre_apellidos IS NULL) THEN
    RAISE E_NOMBRES_NUL;  
  END IF;
    --Busco en la tabla de parlamentos si existe un parlamento con este id
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO 
    WHERE IDPARLAMENTO=id_parlamento
    AND FECHABAJA IS NULL;

    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;
    
    

--Busco en la tabla de parlamentarios si existe un parlamentario con este id
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTARIO
    WHERE IDPARLAMENTO=id_parlamento
    AND IDPARLAMENTARIO=id_parlamentario
    AND FECHABAJA IS NULL;

    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTARIO;
    END IF;    

    SELECT COUNT(*) INTO contador 
    FROM PARTIDO
    WHERE IDPARTIDO=id_partido
    AND FECHABAJA IS NULL;
    
    
    IF (contador=0) THEN
      RAISE E_INEX_PARTIDO;
    END IF; 	  
  
  UPDATE PARLAMENTARIO
  SET NOMBREAPELLIDOS=nombre_apellidos,
      IDPARTIDO=id_partido
  WHERE IDPARLAMENTO = id_parlamento AND
        IDPARLAMENTARIO = id_parlamentario;
  
  
  --Obtiene el numero de parlamentarios activos (fecha de baja como nulo)
  --que tienen asociado este parlamento
  
  SELECT COUNT (*) INTO contador
  FROM PARLAMENTARIO
  WHERE IDPARLAMENTO=id_parlamento
  AND FECHABAJA IS NULL;
  
  
  
  UPDATE PARLAMENTO
  SET NUMEROPARLAMENTARIOS=contador
  WHERE IDPARLAMENTO=id_parlamento;
  
  
   -- Fin de las operaciones
   
   rsp := 'OK';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
   COMMIT;   
EXCEPTION
   WHEN E_PARLAMENTARIO_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo id parlamentario es nulo, debe informarse';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);

   WHEN E_PARTIDO_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo id partido es nulo, debe informarse';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
 
   WHEN E_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo nombre es nulo, debe informarse';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
 
  WHEN E_NOMBRES_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo NombreApellidos es nulo, debe informarse';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
 
  WHEN E_INEX_PARLAMENTO
   THEN
   ROLLBACK;   
      rsp :='ERROR: El Parlamento es inexistente';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
 
  WHEN E_INEX_PARLAMENTARIO
   THEN
   ROLLBACK;   
      rsp :='ERROR: El Parlamentario es inexistente';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
       
  WHEN E_INEX_PARTIDO
   THEN
   ROLLBACK;   
      rsp :='ERROR: El Partido es inexistente';
  altalog ('modParlamentario',param_entrada,rsp,rsp2);
 
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('modParlamentario',param_entrada,rsp,rsp2);
 
      
END MODPARLAMENTARIO;
/