create or replace
PROCEDURE modParlamento 
(
  idparlamento_ IN parlamento.idparlamento%TYPE,
  nombre_ IN  parlamento.nombre%TYPE,
  direccionfisica_ IN  parlamento.direccionfisica%TYPE,
  telefono_ IN  parlamento.telefono%TYPE,
  direccionweb_ IN  parlamento.direccionweb%TYPE,
  idestadopais_ IN  parlamento.idestadopais%TYPE,
  idregion_ IN  parlamento.idregion%TYPE,
  rsp OUT VARCHAR2  
) is 
/******************************************************************************
   NOMBRE:      modParlamento
   PROPSITO:   gestiona la modificacion de un parlamento

   PARAMETERS:  _idparlamento,_nombre,_direccionfisica,_telefono,_direccionweb,_idestadopais,_idregion,rsp
   INPUT:      _idparlamento,_nombre,_direccionfisica,_telefono,_direccionweb,_idestadopais,_idregion
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modParlamento('1','Parlamento Espaol','calle Nogal','913211233','1', '1',rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_NUL  EXCEPTION;
E_ESTADOPAIS EXCEPTION;
E_PARLAMENTO_NUL EXCEPTION;
E_INEX_PARLAMENTO EXCEPTION;
E_REGION EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
  	param_entrada:='idparlamento:'||idparlamento_|| 'nombre: '||nombre_||
    'direccion fisica:'||direccionfisica_ ||' telefono:'||telefono_ ||
    'direccion web:'||direccionweb_ || ' id EstadoPais:'||idestadopais_ ||
    'id region:'||idregion_;
    
	--verificamos que los campos no nulos no sean nulos
  --Es obligatorio el nombre del parlamento y el id del parlamento
  --tanto el estadoPais como la region son opcionales
  IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;  
	END IF;
	IF (nombre_ IS NULL) THEN
		RAISE E_NUL;  
	END IF;
  
  
      --Busco en la tabla de parlamentos si existe un parlamento con este id
    SELECT COUNT(*) INTO contador 
    FROM PARLAMENTO 
    WHERE IDPARLAMENTO=idparlamento_
    AND FECHABAJA IS NULL;

    
    IF (contador=0) THEN
      RAISE E_INEX_PARLAMENTO;
    END IF;
    
  IF (idestadopais_ IS NOT NULL) THEN
    --Busco en la tabla de estado pais si existe un estado pais con este id
    SELECT COUNT(*) INTO contador 
    FROM ESTADOPAIS 
    WHERE IDESTADOPAIS=idestadopais_
    AND FECHABAJA IS NULL;

    
    IF (contador=0) THEN
      RAISE E_ESTADOPAIS;
    END IF;
 	END IF;
  
  IF (idregion_ IS NOT NULL) THEN
    --Busco en la tabla de region si existe una region con este id
    SELECT COUNT(*) INTO contador 
    FROM REGION 
    WHERE IDREGION=idregion_
    AND FECHABAJA IS NULL;
    
    
    IF (contador=0) THEN
      RAISE E_REGION;
    END IF;
 	END IF;


  
  UPDATE PARLAMENTO
  SET NOMBRE=nombre_,
  DIRECCIONFISICA=direccionfisica_,
  TELEFONO=telefono_,
  DIRECCIONWEB=direccionweb_,
  IDESTADOPAIS=idestadopais_,
  IDREGION=idregion_
  WHERE IDPARLAMENTO=idparlamento_;
  
   -- Fin de las operaciones
   rsp := 'OK';

  altalog ('modParlamento',param_entrada,rsp,rsp2);
   COMMIT;   
EXCEPTION
  WHEN E_PARLAMENTO_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo idparlamento es nulo, debe informarse';
  altalog ('modParlamento',param_entrada,rsp,rsp2);
   
   WHEN E_NUL
   THEN
   ROLLBACK;   
      rsp :='ERROR: El campo nombre es nulo, debe informarse';
  altalog ('modParlamento',param_entrada,rsp,rsp2);
 
   WHEN E_INEX_PARLAMENTO
   THEN 
   ROLLBACK;   
      rsp :='ERROR: No existe el parlamento';
  altalog ('modParlamento',param_entrada,rsp,rsp2);

  WHEN E_ESTADOPAIS
   THEN
   ROLLBACK;   
      rsp :='ERROR: El identificador de estadoPais es errneo';
  altalog ('modParlamento',param_entrada,rsp,rsp2);
 
  WHEN E_REGION
   THEN
   ROLLBACK;   
      rsp :='ERROR: El identificador de region es errneo';
  altalog ('modParlamento',param_entrada,rsp,rsp2);
 
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
  altalog ('modParlamento',param_entrada,rsp,rsp2);
       
END modParlamento;
/