create or replace
PROCEDURE modPartido (   
   idPartido_     IN    partido.idpartido%TYPE,
   descripcion_ 	  IN   partido.descripcion%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modPartido
   PROPSITO:   gestiona la modificacion de la descripcion de un partido

   PARAMETERS:  idPartido_,descripcion_, rsp
   INPUT:       idPartido_,descripcion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modPartido('1','PP', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_PARTIDO_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_PARTIDO   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idPartido_:'||idPartido_||' descripcion: '||descripcion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idPartido_ IS NULL) THEN
		RAISE E_PARTIDO_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;

 --Busco en la tabla de partidos si existe un partido con este id
    SELECT COUNT(*) INTO contador 
    FROM PARTIDO 
    WHERE IDPARTIDO=idpartido_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_PARTIDO;
    END IF;
    
	 
	UPDATE PARTIDO
  set descripcion = descripcion_
  WHERE IDPARTIDO = idPartido_;



   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modPartido',param_entrada,rsp,rsp2);
   COMMIT;   
EXCEPTION
   WHEN E_PARTIDO_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idpartido es nulo, debe informarse';
  altalog ('modPartido',param_entrada,rsp,rsp2);
 
   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modPartido',param_entrada,rsp,rsp2);
 
   WHEN E_PARTIDO
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de partido con este identificador';
  altalog ('modPartido',param_entrada,rsp,rsp2);
 
   WHEN OTHERS
   THEN
   ROLLBACK;   
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('modPartido',param_entrada,rsp,rsp2);
 
END modPartido;
/