create or replace
PROCEDURE modRegion (   
   idRegion_     IN    region.idregion%TYPE,
   descripcion_ 	  IN   region.descripcion%TYPE,
   rsp              OUT   VARCHAR2
)
IS
/******************************************************************************
   NOMBRE:      modRegion
   PROPSITO:   gestiona la modificacion de la descripcion de una region

   PARAMETERS:  idRegion_,descripcion_, rsp
   INPUT:       idRegion_,descripcion_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     modRegion('1','Catalua', rsp)
   NOTAS: -
******************************************************************************/
param_entrada	  VARCHAR2(500);
err_msg        	VARCHAR2 (100);
contador      INTEGER;
E_REGION_NUL  EXCEPTION;
E_DESCRIP_NUL  EXCEPTION;
E_REGION   EXCEPTION;
rsp2 VARCHAR2(200);
BEGIN
	param_entrada:= 'idRegion:'||idRegion_||' descripcion: '||descripcion_;

	--verificamos que los campos no nulos no sean nulos
	IF (idRegion_ IS NULL) THEN
		RAISE E_REGION_NUL;
	END IF;
  
	IF (descripcion_ IS NULL) THEN
		RAISE E_DESCRIP_NUL;
	END IF;

 --Busco en la tabla de regiones si existe una region con este id
    SELECT COUNT(*) INTO contador 
    FROM REGION 
    WHERE IDREGION=idRegion_
    AND FECHABAJA IS NULL;
    
    IF (contador=0) THEN
      RAISE E_REGION;
    END IF;
    
	 
	UPDATE REGION
  set descripcion = descripcion_
  WHERE IDREGION = idRegion_;

   -- Fin de las operaciones
   rsp := 'OK';
  altalog ('modRegion',param_entrada,rsp,rsp2);
   COMMIT;   
EXCEPTION
   WHEN E_REGION_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo idRegion es nulo, debe informarse';
  altalog ('modRegion',param_entrada,rsp,rsp2);

   WHEN E_DESCRIP_NUL
   THEN
   ROLLBACK;   
      rsp := 'ERROR: El campo descripcin es nulo, debe informarse';
  altalog ('modRegion',param_entrada,rsp,rsp2);
 
   WHEN E_REGION
   THEN
   ROLLBACK;   
      rsp := 'ERROR: No se encuentra un registro de region con este identificador';
  altalog ('modRegion',param_entrada,rsp,rsp2);
 
   WHEN OTHERS
   THEN
      ROLLBACK;
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;

  altalog ('modRegion',param_entrada,rsp,rsp2); 
END modRegion;
/