create or replace
FUNCTION CONSULTA_R6a (
  idparlamento_   IN  HISTORICOGASTOPARLAMENTARIO.idparlamento%TYPE,
  anyo_           IN  INTEGER,
  idparlamentario_ IN  HISTORICOGASTOPARLAMENTARIO.idparlamentario%TYPE
)
      RETURN TA_R6a
    IS
/******************************************************************************
   Nombre:                 CONSULTA_R6a
   Objetivo:            Dado un parlamento, un ao y un parlamentario: el listado de todos los gastos
                        associados al parlamentario en aquel ao.
                        Todo esto ordenado de forma descendente por el valor de cada gasto.


   PARAMETERS:  idparlamento_,anyo_,idparlamentario_,rsp
   INPUT:       idparlamento_,anyo_,idparlamentario_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     CONSULTA_R6a('1','2012','6')
******************************************************************************/
      l_rc sys_refcursor;
      param_entrada	  VARCHAR2(500);
      err_msg        	VARCHAR2 (100);
      E_PARLAMENTO_NUL  EXCEPTION;
      E_PARLAMENTARIO_NUL EXCEPTION;
      E_FECHA_NUL EXCEPTION;
	  resultado       TA_R6a:=TA_R6a();
	  idcat_ NUMBER;
	  gast_	VARCHAR(200);
	  imp_	NUMBER;
	  nif_	VARCHAR(200);
	  desc_textual_ VARCHAR(200);
	  just_textual_ VARCHAR(200);
	  url_			VARCHAR(200);
	  idestadoG_	NUMBER;
	  estad_		VARCHAR(200);
	  idforma_		NUMBER;
	  forma_		VARCHAR(200);
	  i              INTEGER:=1;
	  rsp 			VARCHAR2(200);
    rsp2 VARCHAR2(200);    
    BEGIN
      param_entrada:= ' idparlamento: '||idparlamento_||' anyo: '||anyo_||
    ' idparlamentario:'||idparlamentario_ ;

--verificamos que los campos no nulos no sean nulos
  IF (anyo_ IS NULL) THEN
		RAISE E_FECHA_NUL;
  END IF;
  IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;
  END IF;
  IF (idparlamentario_ IS NULL) THEN
		RAISE E_PARLAMENTARIO_NUL;
  END IF;
      OPEN l_rc FOR
        SELECT H.IDCATEGORIAGASTO,G.DESCRIPCION AS GASTO, H.IMPORTESINIVA, H.NIFEMPRESA, H.DESCRIPCIONTEXTUAL, H.JUSTIFICACIONTEXTUAL, H.URLINFORMACION, H.IDESTADOGASTO, EG.DESCRIPCION AS ESTADO, H.IDFORMAPAGO, FP.DESCRIPCION AS FORMAPAGO
        FROM HISTORICOGASTOPARLAMENTARIO H, GASTO G, GASTOPARLAMENTARIO GP, FORMAPAGO FP,  ESTADOGASTO EG
        WHERE H.IDPARLAMENTO=idparlamento_
        AND H.IDPARLAMENTARIO=idparlamentario_
        AND TO_CHAR(H.FECHA,'YYYY')=anyo_
        AND GP.IDCATEGORIAGASTO=H.IDCATEGORIAGASTO
        AND GP.IDCATEGORIAGASTO=G.IDCATEGORIAGASTO
        AND FP.IDFORMAPAGO=H.IDFORMAPAGO
        AND EG.IDESTADOGASTO=H.IDESTADOGASTO
        ORDER BY H.IMPORTESINIVA DESC;

	 LOOP
     FETCH l_rc INTO idcat_, gast_, imp_, nif_, desc_textual_, just_textual_, url_, idestadoG_, estad_, idforma_, forma_;
     EXIT WHEN l_rc%NOTFOUND;
       resultado.extend;
       resultado(i):= TY_R6a(idcat_, gast_, imp_, nif_, desc_textual_, just_textual_, url_, idestadoG_, estad_, idforma_, forma_);
       i:= i+1;
   END LOOP;
   CLOSE l_rc;
    rsp :='OK';
    altalog ('CONSULTA_R6a',param_entrada,rsp,rsp2);
	 RETURN resultado;
EXCEPTION
   WHEN E_PARLAMENTO_NUL
   THEN
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
      altalog ('CONSULTA_R6a',param_entrada,rsp,rsp2);
       return null;
  WHEN E_PARLAMENTARIO_NUL
   THEN
      rsp :='ERROR: El campo parlamentario es nulo, debe informarse';
      altalog ('CONSULTA_R6a',param_entrada,rsp,rsp2);
      return null;
   WHEN E_FECHA_NUL
   THEN
      rsp :='ERROR: El campo ao es nulo, debe informarse';
      altalog ('CONSULTA_R6a',param_entrada,rsp,rsp2);
       return null;
   WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
      altalog ('CONSULTA_R6a',param_entrada,rsp,rsp2);             
      return null;
   END;
/