create or replace
FUNCTION CONSULTA_R6b (
  idparlamento_   IN  HISTORICOGASTOPARLAMENTARIO.idparlamento%TYPE,
  anyo_           IN  INTEGER
)
      RETURN TA_R6b
    IS
/******************************************************************************
   Nombre:                 CONSULTA_R6b
   Objetivo:           Dado un parlamento, y un ao: el listado de los parlamentarios con el gasto directo que ha hecho cada uno,incluyendo:
                      Nombre y apellidos
                      Partido poltico actual
                      Suma de todos los gastos directos
                      Ordenado de forma descendente por el valor de la suma de los gastos



   PARAMETERS:  idparlamento_,anyo_,rsp
   INPUT:       idparlamento_,anyo_,
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     CONSULTA_R6b('1','2012')
******************************************************************************/
      l_rc sys_refcursor;
      param_entrada	  VARCHAR2(500);
      err_msg        	VARCHAR2 (100);
      E_PARLAMENTO_NUL  EXCEPTION;
      E_FECHA_NUL EXCEPTION;
	  resultado       TA_R6b:=TA_R6b();
	  nombreap_		VARCHAR(200);
	  part_act_		VARCHAR(200);
	  tot_			NUMBER(10,2);
	  i             INTEGER:=1;
	  rsp 			VARCHAR2(200);
    rsp2 VARCHAR2(200);    
    BEGIN
      param_entrada:= ' idparlamento: '||idparlamento_||' anyo: '||anyo_;

--verificamos que los campos no nulos no sean nulos
  IF (anyo_ IS NULL) THEN
		RAISE E_FECHA_NUL;
  END IF;
  IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;
  END IF;
      OPEN l_rc FOR
        SELECT NOMBREAPELLIDOS,P.DESCRIPCION AS PARTIDO_ACTUAL, TOTAL
        FROM PARTIDO P,(SELECT PARL.IDPARLAMENTO, PARL.IDPARLAMENTARIO, PARL.IDPARTIDO,PARL.NOMBREAPELLIDOS, SUM(H.IMPORTESINIVA) AS TOTAL
        FROM HISTORICOGASTOPARLAMENTARIO H, PARLAMENTARIO PARL
        WHERE PARL.IDPARLAMENTO=idparlamento_
        AND TO_CHAR(H.FECHA,'YYYY')=anyo_
        AND PARL.IDPARLAMENTARIO=H.IDPARLAMENTARIO
        AND PARL.IDPARLAMENTO=H.IDPARLAMENTO
        GROUP BY PARL.IDPARLAMENTO, PARL.IDPARLAMENTARIO, PARL.IDPARTIDO,PARL.NOMBREAPELLIDOS
        ) RES
        WHERE P.IDPARTIDO=RES.IDPARTIDO
        ORDER BY TOTAL DESC;

	 LOOP
     FETCH l_rc INTO nombreap_, part_act_, tot_;
     EXIT WHEN l_rc%NOTFOUND;
       resultado.extend;
       resultado(i):= TY_R6b(nombreap_, part_act_, tot_);
       i:= i+1;
	 END LOOP;
	 CLOSE l_rc;
  rsp:='OK';
    altalog ('CONSULTA_R6b',param_entrada,rsp,rsp2);                          
	 RETURN resultado;
EXCEPTION
   WHEN E_PARLAMENTO_NUL
   THEN
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
    altalog ('CONSULTA_R6b',param_entrada,rsp,rsp2);                                
       return null;
   WHEN E_FECHA_NUL
   THEN
      rsp :='ERROR: El campo ao es nulo, debe informarse';
    altalog ('CONSULTA_R6b',param_entrada,rsp,rsp2);                                
       return null;
   WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
    altalog ('CONSULTA_R6b',param_entrada,rsp,rsp2);                                       
      return null;
   END;
/