create or replace
FUNCTION CONSULTA_R6c (
  anyo_                   IN  INTEGER
)
      RETURN TA_R6c
    IS
/******************************************************************************
   Nombre:                 CONSULTA_R6c
   Objetivo:           Dado un ao: el listado de gasto total de todos los parlamentos, incluyendo:
                      Nombre del parlamento
                      Nmero de parlamentarios
                      Gasto medio de sus parlamentarios
                      Suma de los gastos totales asociados a los parlamentarios
                      Suma de los gastos totales asociados al parlamento
                      Suma total

   PARAMETERS:  anyo_,rsp
   INPUT:       anyo_
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     CONSULTA_R6c('2012')
******************************************************************************/
      l_rc sys_refcursor;
      param_entrada	  VARCHAR2(500);
      err_msg        	VARCHAR2 (100);
      E_FECHA_NUL EXCEPTION;
	  resultado       TA_R6c:=TA_R6c();
	  nom_				VARCHAR(200);
	  numparla_			NUMBER;
	  med_par_			NUMBER(10,2);
	  tot_parls_		NUMBER(10,2);
	  tot_parlm_		NUMBER(10,2);
      tot_				NUMBER(10,2);
	  i             INTEGER:=1;
	  rsp 			VARCHAR2(200);
    rsp2 VARCHAR2(200);        
    BEGIN
      param_entrada:= ' anyo: '||anyo_;

--verificamos que los campos no nulos no sean nulos
  IF (anyo_ IS NULL) THEN
		RAISE E_FECHA_NUL;
  END IF;

      OPEN l_rc FOR
       SELECT NOMBRE, NUMEROPARLAMENTARIOS, MEDIA_PARL AS MEDIA_PARLAMENTARIOS,
       TOT_PARL AS TOTAL_PARLAMENTARIOS,
       TOT_PARLAMENTO AS TOTAL_PARLAMENTO,
       MEDIA_PARL+TOT_PARL+TOT_PARLAMENTO AS TOTAL
        FROM (  SELECT PARL.NOMBRE, PARL.NUMEROPARLAMENTARIOS,
        NVL(CONSULTA_AUX_MED_PARLAMENTARIO(PARL.IDPARLAMENTO,anyo_),0) AS MEDIA_PARL,
        NVL(CONSULTA_AUX_TOT_PARLAMENTARIO(PARL.IDPARLAMENTO,anyo_),0) AS TOT_PARL,
        NVL(CONSULTA_AUX_TOT_PARLAMENTO(PARL.IDPARLAMENTO,anyo_),0) AS TOT_PARLAMENTO
        FROM PARLAMENTO PARL
        );

	 LOOP
     FETCH l_rc INTO  nom_, numparla_, med_par_, tot_parls_, tot_parlm_, tot_;
     EXIT WHEN l_rc%NOTFOUND;
       resultado.extend;
       resultado(i):= TY_R6c(nom_, numparla_, med_par_, tot_parls_, tot_parlm_, tot_);
       i:= i+1;
	 END LOOP;
	 CLOSE l_rc;
  rsp:='OK';
      altalog ('CONSULTA_R6c',param_entrada,rsp,rsp2);                          
	 RETURN resultado;

EXCEPTION
   WHEN E_FECHA_NUL
   THEN
      rsp :='ERROR: El campo ao es nulo, debe informarse';
      altalog ('CONSULTA_R6c',param_entrada,rsp,rsp2);                                
       return null;
   WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
      altalog ('CONSULTA_R6c',param_entrada,rsp,rsp2);                                       
      return null;
   END;
/