create or replace
FUNCTION CONSULTA_R6d (
  idparlamento_   IN  HISTORICOGASTOPARLAMENTO.idparlamento%TYPE,
  anyo_           IN  INTEGER
)
      RETURN TA_R6d
    IS
/******************************************************************************
   Nombre:                 CONSULTA_R6d
   Objetivo:           Dado un parlamento, y un ao: el listado del gasto segmentado por categoras de gasto, es decir un listado que retorne
                      las columnas siguientes:
                      Cdigo de la categora de gasto
                      Descripcin de la categora de gasto
                      Suma de los gastos totales asociadas a las categoras de gasto durante el ao indicado y en el parlamento indicado



   PARAMETERS:  idparlamento_,anyo_,rsp
   INPUT:       idparlamento_,anyo_,
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     CONSULTA_R6d('1','2012')
******************************************************************************/
      l_rc sys_refcursor;
      param_entrada	  VARCHAR2(500);
      err_msg        	VARCHAR2 (100);
      E_PARLAMENTO_NUL  EXCEPTION;
      E_FECHA_NUL EXCEPTION;
	  resultado       TA_R6d:=TA_R6d();
	  cat_			NUMBER;
	  desc_			VARCHAR(200);
	  tot_			NUMBER(10,2);
	  i             INTEGER:=1;
	  rsp	VARCHAR(200);
    rsp2 VARCHAR2(200);        
    BEGIN
      param_entrada:= ' idparlamento: '||idparlamento_||' anyo: '||anyo_;

--verificamos que los campos no nulos no sean nulos
  IF (anyo_ IS NULL) THEN
		RAISE E_FECHA_NUL;
  END IF;
  IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;
  END IF;
      OPEN l_rc FOR
        SELECT H.IDCATEGORIAGASTO,G.DESCRIPCION AS GASTO, SUM(H.IMPORTESINIVA) AS TOTAL
        FROM HISTORICOGASTOPARLAMENTO H, GASTO G, GASTOPARLAMENTO GP
        WHERE H.IDPARLAMENTO=idparlamento_
        AND TO_CHAR(H.FECHA,'YYYY')=anyo_
        AND GP.IDCATEGORIAGASTO=H.IDCATEGORIAGASTO
        AND GP.IDCATEGORIAGASTO=G.IDCATEGORIAGASTO
        GROUP BY H.IDCATEGORIAGASTO,G.DESCRIPCION
        ORDER BY TOTAL DESC;

	 LOOP

     FETCH l_rc INTO cat_, desc_, tot_;
     EXIT WHEN l_rc%NOTFOUND;
       resultado.extend;
       resultado(i):= TY_R6d(cat_, desc_, tot_);
       i:= i+1;
	 END LOOP;
	 CLOSE l_rc;
      rsp:='OK';
      altalog ('CONSULTA_R6d',param_entrada,rsp,rsp2);                          
	 RETURN resultado;
EXCEPTION
   WHEN E_PARLAMENTO_NUL
   THEN
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
      altalog ('CONSULTA_R6d',param_entrada,rsp,rsp2);                                
       return null;
   WHEN E_FECHA_NUL
   THEN
      rsp :='ERROR: El campo ao es nulo, debe informarse';
      altalog ('CONSULTA_R6d',param_entrada,rsp,rsp2);                                
       return null;
   WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
      altalog ('CONSULTA_R6d',param_entrada,rsp,rsp2);                                       
      return null;
   END;
/