create or replace
FUNCTION CONSULTA_R6e (
  idparlamento_   IN  PARLAMENTO.idparlamento%TYPE,
  anyo_           IN  INTEGER
)
      RETURN TA_R6e
    IS
/******************************************************************************
   Nombre:                 CONSULTA_R6e
   Objetivo:           Dado un parlamento y un ao: el listado de parlamentarios que superan el gasto medio de todos los parlamentarios de este
                      parlamento durante el ao indicado, incluyendo:
                      Nombre y apellidos
                      Partido poltico actual
                      Suma de todos los gastos directos asociados al parlamentario durante ese ao
                      El porcentaje en que se supera el gasto medio.



   PARAMETERS:  idparlamento_,anyo_,rsp
   INPUT:       idparlamento_,anyo_,
   OUTPUT:      rsp
   RETORNA:     'OK' si la operacin ha sido exitosa
                'ERROR: Tipo de Error' en caso contrario
   EJEMPLO DE USO:     CONSULTA_R6e('1','2012')
******************************************************************************/
      l_rc sys_refcursor;
      media           NUMBER(10,2);
      param_entrada	  VARCHAR2(500);
      err_msg        	VARCHAR2 (100);
      E_PARLAMENTO_NUL  EXCEPTION;
      E_FECHA_NUL EXCEPTION;
	  resultado       TA_R6e:=TA_R6e();
	  nombreap_		VARCHAR(200);
	  part_			VARCHAR(200);
	  tot_			NUMBER(10,2);
	  porc_			VARCHAR(100);
	  i             INTEGER:=1;
	  rsp	VARCHAR(200);
    rsp2 VARCHAR2(200);        
    BEGIN
      param_entrada:= ' idparlamento: '||idparlamento_||' anyo: '||anyo_;

--verificamos que los campos no nulos no sean nulos
  IF (anyo_ IS NULL) THEN
		RAISE E_FECHA_NUL;
  END IF;
  IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;
  END IF;

  --primero busco la media de gasto de los parlamentarios
  --para ello agrupo por parlamentario, para saber el gasto total de cada uno
  --finalmente asigno a la variable media el promedio global
  SELECT NVL(AVG(TOTAL),0) AS PROMEDIO INTO media
    FROM
    (
    SELECT IDPARLAMENTO,IDPARLAMENTARIO, NVL(SUM(hg.importesiniva),0) AS TOTAL
    FROM HISTORICOGASTOPARLAMENTARIO HG
    WHERE IDPARLAMENTO=idparlamento_
    AND TO_CHAR(FECHA,'YYYY')=anyo_
    GROUP BY IDPARLAMENTO,IDPARLAMENTARIO
    );


      OPEN l_rc FOR
        SELECT NOMBREAPELLIDOS, PARTIDO,  TOTAL, Round((TOTAL/media),2)*100 -100||'%' AS PORCENTAJE
        FROM
        (
        SELECT PARL.NOMBREAPELLIDOS, HG.IDPARLAMENTO,HG.IDPARLAMENTARIO, PARL.IDPARTIDO,P.DESCRIPCION AS PARTIDO,  NVL(SUM(HG.importesiniva),0) AS TOTAL
        FROM HISTORICOGASTOPARLAMENTARIO HG, PARLAMENTARIO PARL,PARTIDO P
        WHERE HG.IDPARLAMENTO=idparlamento_
        AND TO_CHAR(HG.FECHA,'YYYY')=anyo_
        AND PARL.IDPARLAMENTO=HG.IDPARLAMENTO
        AND PARL.IDPARLAMENTARIO=HG.IDPARLAMENTARIO
        AND P.IDPARTIDO=PARL.IDPARTIDO
        GROUP BY PARL.NOMBREAPELLIDOS, HG.IDPARLAMENTO,HG.IDPARLAMENTARIO,PARL.IDPARTIDO,P.DESCRIPCION
        )
        WHERE TOTAL>media;

	 LOOP

     FETCH l_rc INTO nombreap_, part_, tot_, porc_;
     EXIT WHEN l_rc%NOTFOUND;
       resultado.extend;
       resultado(i):= TY_R6e(nombreap_, part_, tot_, porc_);
       i:= i+1;
	 END LOOP;
	 CLOSE l_rc;
  rsp:='OK';
      altalog ('CONSULTA_R6e',param_entrada,rsp,rsp2);                            
	 RETURN resultado;
EXCEPTION
   WHEN E_PARLAMENTO_NUL
   THEN
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
      altalog ('CONSULTA_R6e',param_entrada,rsp,rsp2);                                  
       return null;
   WHEN E_FECHA_NUL
   THEN
      rsp :='ERROR: El campo ao es nulo, debe informarse';
      altalog ('CONSULTA_R6e',param_entrada,rsp,rsp2);                                  
       return null;
   WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
      altalog ('CONSULTA_R6e',param_entrada,rsp,rsp2);                                         
      return null;
   END;
/