create or replace
FUNCTION CONSULTA_AUX_TOTAL_G_ESTADO (
  idparlamento_   IN  HISTORICOGASTOPARLAMENTO.idparlamento%TYPE,
  anyo_           IN  INTEGER,
  idestadogasto_   IN  HISTORICOGASTOPARLAMENTO.idestadogasto%TYPE
)
      RETURN NUMBER
    IS
/******************************************************************************
   Nombre:                 CONSULTA_AUX_TOTAL_G_ESTADO
   Objetivo:           Dado un parlamento, un ao y un estado de gasto
                      Retorna el importe total de gastos con este estado durante el ao para el parlamento indicado

                   
   PARAMETERS:  idparlamento_,anyo_,idestadogasto_,rsp
   INPUT:       idparlamento_,anyo_,idestadogasto_
   RETORNA:     El resultado
   EJEMPLO DE USO:     CONSULTA_AUX_TOTAL_G_ESTADO('1','2012','1')
******************************************************************************/    
      res NUMBER(10,2);
      param_entrada	  VARCHAR2(500);
      err_msg        	VARCHAR2 (100);  
      E_PARLAMENTO_NUL  EXCEPTION;
      E_FECHA_NUL EXCEPTION;
    rsp2 VARCHAR2(200);          
    rsp VARCHAR2(200);
    BEGIN
      param_entrada:= ' idparlamento: '||idparlamento_||' anyo: '||anyo_;
    
--verificamos que los campos no nulos no sean nulos
  IF (anyo_ IS NULL) THEN
		RAISE E_FECHA_NUL;  
  END IF;
  IF (idparlamento_ IS NULL) THEN
		RAISE E_PARLAMENTO_NUL;  
  END IF;
        SELECT SUM(H.IMPORTESINIVA) AS TOTAL INTO res
        FROM HISTORICOGASTOPARLAMENTO H, ESTADOGASTO EG
        WHERE H.IDPARLAMENTO=idparlamento_
        AND TO_CHAR(H.FECHA,'YYYY')=anyo_
        AND H.IDESTADOGASTO=EG.IDESTADOGASTO        
        AND H.IDESTADOGASTO=idestadogasto_;
        rsp := 'OK';
    altalog ('CONSULTA_AUX_TOTAL_G_ESTADO',param_entrada,rsp,rsp2);                        
     RETURN res;
EXCEPTION
   WHEN E_PARLAMENTO_NUL
   THEN
      rsp :='ERROR: El campo parlamento es nulo, debe informarse';
    altalog ('CONSULTA_AUX_TOTAL_G_ESTADO',param_entrada,rsp,rsp2);                              
       return null;
   WHEN E_FECHA_NUL
   THEN
      rsp :='ERROR: El campo ao es nulo, debe informarse';             
    altalog ('CONSULTA_AUX_TOTAL_G_ESTADO',param_entrada,rsp,rsp2);                              
       return null;
   WHEN OTHERS
   THEN
      err_msg := SUBSTR (SQLERRM, 1, 100);
      rsp :=    'ERROR:'
             || err_msg;
    altalog ('CONSULTA_AUX_TOTAL_G_ESTADO',param_entrada,rsp,rsp2);                                     
      return null;
   END;
/